/* automatically generated from terminal-preferences.glade */
#ifdef __SUNPRO_C
#pragma align 4 (terminal_preferences_ui)
#endif
#ifdef __GNUC__
static const char terminal_preferences_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char terminal_preferences_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.14\"/><object class=\"GtkAdjustment\" id=\"background-"
  "darkness\"><property name=\"upper\">1</property><property name=\"step-i"
  "ncrement\">0.01</property><property name=\"page-increment\">0.10</prope"
  "rty></object><object class=\"GtkAdjustment\" id=\"background-image-shad"
  "ing\"><property name=\"upper\">1</property><property name=\"step-increm"
  "ent\">0.01</property><property name=\"page-increment\">0.10</property><"
  "/object><object class=\"GtkAdjustment\" id=\"cell-height-scale\"><prope"
  "rty name=\"lower\">1</property><property name=\"upper\">2</property><pr"
  "operty name=\"value\">1</property><property name=\"step-increment\">0.0"
  "5</property><property name=\"page-increment\">0.25</property></object><"
  "object class=\"GtkAdjustment\" id=\"cell-width-scale\"><property name=\""
  "lower\">1</property><property name=\"upper\">2</property><property name"
  "=\"value\">1</property><property name=\"step-increment\">0.05</property"
  "><property name=\"page-increment\">0.25</property></object><object clas"
  "s=\"GtkAdjustment\" id=\"dropdown-animation-time\"><property name=\"upp"
  "er\">500</property><property name=\"step-increment\">1</property><prope"
  "rty name=\"page-increment\">10</property></object><object class=\"GtkAd"
  "justment\" id=\"dropdown-height\"><property name=\"lower\">10</property"
  "><property name=\"upper\">100</property><property name=\"step-increment"
  "\">1</property><property name=\"page-increment\">10</property></object>"
  "<object class=\"GtkAdjustment\" id=\"dropdown-opacity\"><property name="
  "\"upper\">100</property><property name=\"step-increment\">1</property><"
  "property name=\"page-increment\">10</property></object><object class=\""
  "GtkAdjustment\" id=\"dropdown-position\"><property name=\"upper\">100</"
  "property><property name=\"step-increment\">1</property><property name=\""
  "page-increment\">10</property></object><object class=\"GtkAdjustment\" "
  "id=\"dropdown-position-vertical\"><property name=\"upper\">100</propert"
  "y><property name=\"step-increment\">1</property><property name=\"page-i"
  "ncrement\">10</property></object><object class=\"GtkAdjustment\" id=\"d"
  "ropdown-width\"><property name=\"lower\">10</property><property name=\""
  "upper\">100</property><property name=\"step-increment\">1</property><pr"
  "operty name=\"page-increment\">10</property></object><object class=\"Gt"
  "kAdjustment\" id=\"geo-columns\"><property name=\"lower\">1</property><"
  "property name=\"upper\">1000</property><property name=\"value\">80</pro"
  "perty><property name=\"step-increment\">1</property><property name=\"pa"
  "ge-increment\">10</property></object><object class=\"GtkAdjustment\" id"
  "=\"geo-rows\"><property name=\"lower\">1</property><property name=\"upp"
  "er\">1000</property><property name=\"value\">24</property><property nam"
  "e=\"step-increment\">1</property><property name=\"page-increment\">10</"
  "property></object><object class=\"GtkListStore\" id=\"liststore1\"><col"
  "umns><column type=\"gchararray\"/></columns><data><row><col id=\"0\" tr"
  "anslatable=\"yes\">Replaces initial title</col></row><row><col id=\"0\""
  " translatable=\"yes\">Goes before initial title</col></row><row><col id"
  "=\"0\" translatable=\"yes\">Goes after initial title</col></row><row><c"
  "ol id=\"0\" translatable=\"yes\">Isn\'t displayed</col></row></data></o"
  "bject><object class=\"GtkListStore\" id=\"liststore10\"><columns><colum"
  "n type=\"gchararray\"/></columns><data><row><col id=\"0\" translatable="
  "\"yes\">Context Menu</col></row><row><col id=\"0\" translatable=\"yes\""
  ">Paste Clipboard</col></row><row><col id=\"0\" translatable=\"yes\">Pas"
  "te Selection</col></row></data></object><object class=\"GtkListStore\" "
  "id=\"liststore2\"><columns><column type=\"gchararray\"/></columns><data"
  "><row><col id=\"0\" translatable=\"yes\">Disabled</col></row><row><col "
  "id=\"0\" translatable=\"yes\">On the left side</col></row><row><col id="
  "\"0\" translatable=\"yes\">On the right side</col></row></data></object"
  "><object class=\"GtkListStore\" id=\"liststore3\"><columns><column type"
  "=\"gchararray\"/></columns><data><row><col id=\"0\" translatable=\"yes\""
  ">None (use solid color)</col></row><row><col id=\"0\" translatable=\"ye"
  "s\">Background image</col></row><row><col id=\"0\" translatable=\"yes\""
  ">Transparent background</col></row></data></object><object class=\"GtkL"
  "istStore\" id=\"liststore4\"><columns><column type=\"gchararray\"/></co"
  "lumns><data><row><col id=\"0\" translatable=\"yes\">Auto-detect</col></"
  "row><row><col id=\"0\" translatable=\"yes\">ASCII DEL</col></row><row><"
  "col id=\"0\" translatable=\"yes\">Escape sequence</col></row><row><col "
  "id=\"0\" translatable=\"yes\">Control-H</col></row><row><col id=\"0\" t"
  "ranslatable=\"yes\">Erase TTY</col></row></data></object><object class="
  "\"GtkListStore\" id=\"liststore5\"><columns><column type=\"gchararray\""
  "/></columns><data><row><col id=\"0\" translatable=\"yes\">Auto-detect</"
  "col></row><row><col id=\"0\" translatable=\"yes\">ASCII DEL</col></row>"
  "<row><col id=\"0\" translatable=\"yes\">Escape sequence</col></row><row"
  "><col id=\"0\" translatable=\"yes\">Control-H</col></row><row><col id=\""
  "0\" translatable=\"yes\">Erase TTY</col></row></data></object><object c"
  "lass=\"GtkListStore\" id=\"liststore6\"><columns><column type=\"gcharar"
  "ray\"/></columns><data><row><col id=\"0\" translatable=\"yes\">Tiled</c"
  "ol></row><row><col id=\"0\" translatable=\"yes\">Centered</col></row><r"
  "ow><col id=\"0\" translatable=\"yes\">Scaled</col></row><row><col id=\""
  "0\" translatable=\"yes\">Stretched</col></row><row><col id=\"0\" transl"
  "atable=\"yes\">Filled</col></row></data></object><object class=\"GtkLis"
  "tStore\" id=\"liststore7\"><columns><column type=\"gchararray\"/></colu"
  "mns><data><row><col id=\"0\" translatable=\"yes\">Block</col></row><row"
  "><col id=\"0\" translatable=\"yes\">I-Beam</col></row><row><col id=\"0\""
  " translatable=\"yes\">Underline</col></row></data></object><object clas"
  "s=\"GtkListStore\" id=\"liststore8\"><columns><column type=\"gchararray"
  "\"/></columns><data><row><col id=\"0\" translatable=\"yes\">Narrow</col"
  "></row><row><col id=\"0\" translatable=\"yes\">Wide</col></row></data><"
  "/object><object class=\"GtkListStore\" id=\"liststore9\"><columns><colu"
  "mn type=\"gchararray\"/></columns><data><row><col id=\"0\" translatable"
  "=\"yes\">Never</col></row><row><col id=\"0\" translatable=\"yes\">When "
  "focused</col></row><row><col id=\"0\" translatable=\"yes\">When unfocus"
  "ed</col></row><row><col id=\"0\" translatable=\"yes\">Always</col></row"
  "></data></object><object class=\"GtkAdjustment\" id=\"scrolling-line\">"
  "<property name=\"lower\">1</property><property name=\"upper\">5242880</"
  "property><property name=\"step-increment\">1</property><property name=\""
  "page-increment\">10</property></object><object class=\"GtkAdjustment\" "
  "id=\"tab-activity-timeout\"><property name=\"upper\">30</property><prop"
  "erty name=\"step-increment\">1</property><property name=\"page-incremen"
  "t\">10</property></object><object class=\"GtkDialog\" id=\"dialog\"><pr"
  "operty name=\"can-focus\">False</property><property name=\"title\" tran"
  "slatable=\"yes\">Terminal Preferences</property><property name=\"icon-n"
  "ame\">gtk-preferences</property><property name=\"type-hint\">normal</pr"
  "operty><child internal-child=\"vbox\"><object class=\"GtkBox\" id=\"dia"
  "log-vbox1\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">False</property><property name=\"orientation\">vertical</pr"
  "operty><property name=\"spacing\">2</property><child internal-child=\"a"
  "ction_area\"><object class=\"GtkButtonBox\" id=\"dialog-action_area1\">"
  "<property name=\"visible\">True</property><property name=\"can-focus\">"
  "False</property><property name=\"layout-style\">end</property><child><o"
  "bject class=\"GtkButton\" id=\"button-help\"><property name=\"label\">g"
  "tk-help</property><property name=\"visible\">True</property><property n"
  "ame=\"can-focus\">True</property><property name=\"receives-default\">Tr"
  "ue</property><property name=\"use-stock\">True</property></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">F"
  "alse</property><property name=\"position\">0</property><property name=\""
  "secondary\">True</property></packing></child><child><object class=\"Gtk"
  "Button\" id=\"button-close\"><property name=\"label\">gtk-close</proper"
  "ty><property name=\"visible\">True</property><property name=\"can-focus"
  "\">True</property><property name=\"receives-default\">True</property><p"
  "roperty name=\"use-stock\">True</property></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">False</property>"
  "<property name=\"position\">1</property></packing></child></object><pac"
  "king><property name=\"expand\">False</property><property name=\"fill\">"
  "True</property><property name=\"pack-type\">end</property><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "Notebook\" id=\"notebook\"><property name=\"visible\">True</property><p"
  "roperty name=\"can-focus\">True</property><property name=\"border-width"
  "\">6</property><child><object class=\"GtkBox\" id=\"vbox1\"><property n"
  "ame=\"visible\">True</property><property name=\"can-focus\">False</prop"
  "erty><property name=\"border-width\">6</property><property name=\"orien"
  "tation\">vertical</property><property name=\"spacing\">6</property><chi"
  "ld><object class=\"GtkFrame\" id=\"frame1\"><property name=\"visible\">"
  "True</property><property name=\"can-focus\">False</property><property n"
  "ame=\"label-xalign\">0</property><property name=\"shadow-type\">none</p"
  "roperty><child><object class=\"GtkGrid\" id=\"grid3\"><property name=\""
  "visible\">True</property><property name=\"can-focus\">False</property><"
  "property name=\"margin-left\">18</property><property name=\"margin-righ"
  "t\">6</property><property name=\"margin-top\">6</property><property nam"
  "e=\"margin-bottom\">6</property><property name=\"row-spacing\">6</prope"
  "rty><property name=\"column-spacing\">12</property><child><object class"
  "=\"GtkLabel\" id=\"label5\"><property name=\"visible\">True</property><"
  "property name=\"can-focus\">False</property><property name=\"halign\">s"
  "tart</property><property name=\"label\" translatable=\"yes\">_Initial t"
  "itle:</property><property name=\"use-underline\">True</property></objec"
  "t><packing><property name=\"left-attach\">0</property><property name=\""
  "top-attach\">0</property></packing></child><child><object class=\"GtkLa"
  "bel\" id=\"label6\"><property name=\"visible\">True</property><property"
  " name=\"can-focus\">False</property><property name=\"halign\">start</pr"
  "operty><property name=\"label\" translatable=\"yes\">_Dynamically-set t"
  "itle:</property><property name=\"use-underline\">True</property></objec"
  "t><packing><property name=\"left-attach\">0</property><property name=\""
  "top-attach\">1</property></packing></child><child><object class=\"GtkEn"
  "try\" id=\"title-initial\"><property name=\"visible\">True</property><p"
  "roperty name=\"can-focus\">True</property><property name=\"hexpand\">Tr"
  "ue</property><property name=\"invisible-char\">\342\200\242</property><"
  "property name=\"primary-icon-activatable\">False</property><property na"
  "me=\"secondary-icon-activatable\">False</property></object><packing><pr"
  "operty name=\"left-attach\">1</property><property name=\"top-attach\">0"
  "</property></packing></child><child><object class=\"GtkComboBox\" id=\""
  "title-mode\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">False</property><property name=\"hexpand\">True</property><"
  "property name=\"model\">liststore1</property><child><object class=\"Gtk"
  "CellRendererText\" id=\"cellrenderertext1\"/><attributes><attribute nam"
  "e=\"text\">0</attribute></attributes></child></object><packing><propert"
  "y name=\"left-attach\">1</property><property name=\"top-attach\">1</pro"
  "perty></packing></child><child><placeholder/></child><child><placeholde"
  "r/></child><child><placeholder/></child><child><placeholder/></child><c"
  "hild><placeholder/></child></object></child><child type=\"label\"><obje"
  "ct class=\"GtkLabel\" id=\"label4\"><property name=\"visible\">True</pr"
  "operty><property name=\"can-focus\">False</property><property name=\"la"
  "bel\" translatable=\"yes\">Title</property><property name=\"use-markup\""
  ">True</property><attributes><attribute name=\"weight\" value=\"bold\"/>"
  "</attributes></object></child></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "Frame\" id=\"frame2\"><property name=\"visible\">True</property><proper"
  "ty name=\"can-focus\">False</property><property name=\"label-xalign\">0"
  "</property><property name=\"shadow-type\">none</property><child><object"
  " class=\"GtkAlignment\" id=\"alignment2\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can-focus\">False</property><property nam"
  "e=\"left-padding\">12</property><child><object class=\"GtkBox\" id=\"vb"
  "ox2\"><property name=\"visible\">True</property><property name=\"can-fo"
  "cus\">False</property><property name=\"border-width\">6</property><prop"
  "erty name=\"orientation\">vertical</property><property name=\"spacing\""
  ">6</property><child><object class=\"GtkCheckButton\" id=\"command-login"
  "-shell\"><property name=\"label\" translatable=\"yes\">_Run command as "
  "login shell</property><property name=\"visible\">True</property><proper"
  "ty name=\"can-focus\">True</property><property name=\"receives-default\""
  ">False</property><property name=\"tooltip-text\" translatable=\"yes\">S"
  "elect this option to force Terminal to run your shell as a login shell "
  "when you open new terminals. See the documentation of your shell for de"
  "tails about differences between running it as interactive shell and run"
  "ning it as login shell.</property><property name=\"halign\">start</prop"
  "erty><property name=\"use-underline\">True</property><property name=\"d"
  "raw-indicator\">True</property></object><packing><property name=\"expan"
  "d\">True</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "CheckButton\" id=\"command-update-records\"><property name=\"label\" tr"
  "anslatable=\"yes\">_Update utmp/wtmp records when command is launched</"
  "property><property name=\"visible\">True</property><property name=\"can"
  "-focus\">True</property><property name=\"receives-default\">False</prop"
  "erty><property name=\"tooltip-text\" translatable=\"yes\">Select this o"
  "ption to allow commands that use utmp/wtmp records (such as `write` or "
  "`wall`) to work.</property><property name=\"halign\">start</property><p"
  "roperty name=\"use-underline\">True</property><property name=\"draw-ind"
  "icator\">True</property></object><packing><property name=\"expand\">Tru"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">1</property></packing></child><child><object class=\"GtkCheckBu"
  "tton\" id=\"run-custom-command\"><property name=\"label\" translatable="
  "\"yes\">Run a _custom command instead of my shell</property><property n"
  "ame=\"visible\">True</property><property name=\"can-focus\">True</prope"
  "rty><property name=\"receives-default\">False</property><property name="
  "\"tooltip-text\" translatable=\"yes\">Select this option to force Termi"
  "nal to run custom command instead of your shell when you open new termi"
  "nals.</property><property name=\"halign\">start</property><property nam"
  "e=\"use-underline\">True</property><property name=\"draw-indicator\">Tr"
  "ue</property></object><packing><property name=\"expand\">True</property"
  "><property name=\"fill\">True</property><property name=\"position\">2</"
  "property></packing></child><child><object class=\"GtkBox\" id=\"hbox3\""
  "><property name=\"visible\">True</property><property name=\"can-focus\""
  ">False</property><property name=\"spacing\">12</property><child><object"
  " class=\"GtkLabel\" id=\"label56\"><property name=\"visible\">True</pro"
  "perty><property name=\"can-focus\">False</property><property name=\"hal"
  "ign\">start</property><property name=\"label\" translatable=\"yes\">C_u"
  "stom command:</property><property name=\"use-underline\">True</property"
  "></object><packing><property name=\"expand\">False</property><property "
  "name=\"fill\">True</property><property name=\"position\">0</property></"
  "packing></child><child><object class=\"GtkEntry\" id=\"custom-command\""
  "><property name=\"visible\">True</property><property name=\"can-focus\""
  ">True</property><property name=\"hexpand\">True</property><property nam"
  "e=\"invisible-char\">\342\200\242</property><property name=\"primary-ic"
  "on-activatable\">False</property><property name=\"secondary-icon-activa"
  "table\">False</property></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">1</property></packing></child></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">3</property></packing></child><child><object cl"
  "ass=\"GtkBox\" id=\"hbox10\"><property name=\"visible\">True</property>"
  "<property name=\"can-focus\">False</property><property name=\"tooltip-t"
  "ext\" translatable=\"yes\">Select this option to make new terminals (ta"
  "bs or windows) use custom working directory. Otherwise, current working"
  " directory will be used.</property><property name=\"spacing\">12</prope"
  "rty><child><object class=\"GtkCheckButton\" id=\"use-default-working-di"
  "r\"><property name=\"label\" translatable=\"yes\">_Working directory:</"
  "property><property name=\"visible\">True</property><property name=\"can"
  "-focus\">True</property><property name=\"receives-default\">False</prop"
  "erty><property name=\"halign\">start</property><property name=\"use-und"
  "erline\">True</property><property name=\"draw-indicator\">True</propert"
  "y></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">True</property><property name=\"position\">0</property><"
  "/packing></child><child><object class=\"GtkEntry\" id=\"default-working"
  "-dir\"><property name=\"visible\">True</property><property name=\"can-f"
  "ocus\">True</property><property name=\"hexpand\">True</property><proper"
  "ty name=\"invisible-char\">\342\200\242</property><property name=\"prim"
  "ary-icon-activatable\">False</property><property name=\"secondary-icon-"
  "activatable\">False</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">1</property></packing></child></object><packing><propert"
  "y name=\"expand\">False</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">4</property></packing></child></object></"
  "child></object></child><child type=\"label\"><object class=\"GtkLabel\""
  " id=\"label7\"><property name=\"visible\">True</property><property name"
  "=\"can-focus\">False</property><property name=\"label\" translatable=\""
  "yes\">Command</property><property name=\"use-markup\">True</property><a"
  "ttributes><attribute name=\"weight\" value=\"bold\"/></attributes></obj"
  "ect></child></object><packing><property name=\"expand\">False</property"
  "><property name=\"fill\">True</property><property name=\"position\">1</"
  "property></packing></child><child><object class=\"GtkFrame\" id=\"frame"
  "3\"><property name=\"visible\">True</property><property name=\"can-focu"
  "s\">False</property><property name=\"label-xalign\">0</property><proper"
  "ty name=\"shadow-type\">none</property><child><object class=\"GtkAlignm"
  "ent\" id=\"alignment3\"><property name=\"visible\">True</property><prop"
  "erty name=\"can-focus\">False</property><property name=\"left-padding\""
  ">12</property><child><object class=\"GtkBox\" id=\"vbox3\"><property na"
  "me=\"visible\">True</property><property name=\"can-focus\">False</prope"
  "rty><property name=\"border-width\">6</property><property name=\"orient"
  "ation\">vertical</property><property name=\"spacing\">6</property><chil"
  "d><object class=\"GtkGrid\" id=\"grid1\"><property name=\"visible\">Tru"
  "e</property><property name=\"can-focus\">False</property><property name"
  "=\"row-spacing\">6</property><property name=\"column-spacing\">12</prop"
  "erty><child><object class=\"GtkLabel\" id=\"label10\"><property name=\""
  "visible\">True</property><property name=\"can-focus\">False</property><"
  "property name=\"halign\">start</property><property name=\"label\" trans"
  "latable=\"yes\">Scroll_back:</property><property name=\"use-underline\""
  ">True</property></object><packing><property name=\"left-attach\">0</pro"
  "perty><property name=\"top-attach\">2</property></packing></child><chil"
  "d><object class=\"GtkSpinButton\" id=\"scrolling-lines\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">True</property"
  "><property name=\"tooltip-text\" translatable=\"yes\">Specifies the num"
  "ber of lines that you can scroll back using the scrollbar.</property><p"
  "roperty name=\"halign\">start</property><property name=\"invisible-char"
  "\">\342\200\242</property><property name=\"primary-icon-activatable\">F"
  "alse</property><property name=\"secondary-icon-activatable\">False</pro"
  "perty><property name=\"adjustment\">scrolling-line</property><property "
  "name=\"numeric\">True</property><property name=\"update-policy\">if-val"
  "id</property></object><packing><property name=\"left-attach\">1</proper"
  "ty><property name=\"top-attach\">2</property></packing></child><child><"
  "object class=\"GtkCheckButton\" id=\"scrolling-unlimited\"><property na"
  "me=\"label\" translatable=\"yes\">Unli_mited scrollback</property><prop"
  "erty name=\"visible\">True</property><property name=\"can-focus\">True<"
  "/property><property name=\"receives-default\">False</property><property"
  " name=\"tooltip-text\" translatable=\"yes\">This option controls whethe"
  "r the terminal will have no limits on scrollback.</property><property n"
  "ame=\"halign\">start</property><property name=\"use-underline\">True</p"
  "roperty><property name=\"draw-indicator\">True</property></object><pack"
  "ing><property name=\"left-attach\">2</property><property name=\"top-att"
  "ach\">2</property></packing></child><child><object class=\"GtkLabel\" i"
  "d=\"label9\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">False</property><property name=\"halign\">start</property><"
  "property name=\"label\" translatable=\"yes\">Scr_ollbar is:</property><"
  "property name=\"use-underline\">True</property></object><packing><prope"
  "rty name=\"left-attach\">0</property><property name=\"top-attach\">1</p"
  "roperty></packing></child><child><object class=\"GtkComboBox\" id=\"scr"
  "olling-bar\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">False</property><property name=\"hexpand\">True</property><"
  "property name=\"model\">liststore2</property><child><object class=\"Gtk"
  "CellRendererText\" id=\"cellrenderertext2\"/><attributes><attribute nam"
  "e=\"text\">0</attribute></attributes></child></object><packing><propert"
  "y name=\"left-attach\">1</property><property name=\"top-attach\">1</pro"
  "perty><property name=\"width\">2</property></packing></child><child><ob"
  "ject class=\"GtkCheckButton\" id=\"scrolling-on-output\"><property name"
  "=\"label\" translatable=\"yes\">Scroll on ou_tput</property><property n"
  "ame=\"visible\">True</property><property name=\"can-focus\">True</prope"
  "rty><property name=\"receives-default\">False</property><property name="
  "\"tooltip-text\" translatable=\"yes\">This option controls whether the "
  "terminal will scroll down automatically whenever new output is generate"
  "d by the commands running inside the terminal.</property><property name"
  "=\"halign\">start</property><property name=\"use-underline\">True</prop"
  "erty><property name=\"draw-indicator\">True</property></object><packing"
  "><property name=\"left-attach\">0</property><property name=\"top-attach"
  "\">0</property></packing></child><child><object class=\"GtkCheckButton\""
  " id=\"scrolling-on-keystroke\"><property name=\"label\" translatable=\""
  "yes\">Scroll on _keystroke</property><property name=\"visible\">True</p"
  "roperty><property name=\"can-focus\">True</property><property name=\"re"
  "ceives-default\">False</property><property name=\"tooltip-text\" transl"
  "atable=\"yes\">Enables you to press any key on the keyboard to scroll d"
  "own the terminal window to the command prompt.</property><property name"
  "=\"halign\">start</property><property name=\"use-underline\">True</prop"
  "erty><property name=\"draw-indicator\">True</property></object><packing"
  "><property name=\"left-attach\">2</property><property name=\"top-attach"
  "\">0</property></packing></child><child><object class=\"GtkCheckButton\""
  " id=\"overlay-scrolling\"><property name=\"label\" translatable=\"yes\""
  ">Enable _overlay scrolling (Requires Restart)</property><property name="
  "\"visible\">True</property><property name=\"can-focus\">True</property>"
  "<property name=\"receives-default\">False</property><property name=\"to"
  "oltip-text\" translatable=\"yes\">This option controls whether the scro"
  "llbar is drawn as an overlay (auto-hide) or not.</property><property na"
  "me=\"halign\">start</property><property name=\"use-underline\">True</pr"
  "operty><property name=\"draw-indicator\">True</property></object><packi"
  "ng><property name=\"left-attach\">1</property><property name=\"top-atta"
  "ch\">0</property></packing></child></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">0</property></packing></child></object></child></ob"
  "ject></child><child type=\"label\"><object class=\"GtkLabel\" id=\"labe"
  "l8\"><property name=\"visible\">True</property><property name=\"can-foc"
  "us\">False</property><property name=\"label\" translatable=\"yes\">Scro"
  "lling</property><property name=\"use-markup\">True</property><attribute"
  "s><attribute name=\"weight\" value=\"bold\"/></attributes></object></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">2</property"
  "></packing></child><child><object class=\"GtkFrame\" id=\"frame18\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Fal"
  "se</property><property name=\"label-xalign\">0</property><property name"
  "=\"shadow-type\">none</property><child><object class=\"GtkAlignment\" i"
  "d=\"alignment18\"><property name=\"visible\">True</property><property n"
  "ame=\"can-focus\">False</property><property name=\"left-padding\">12</p"
  "roperty><child><object class=\"GtkBox\" id=\"vbox18\"><property name=\""
  "visible\">True</property><property name=\"can-focus\">False</property><"
  "property name=\"border-width\">6</property><property name=\"orientation"
  "\">vertical</property><property name=\"spacing\">6</property><child><ob"
  "ject class=\"GtkGrid\" id=\"grid7\"><property name=\"visible\">True</pr"
  "operty><property name=\"can-focus\">False</property><property name=\"ro"
  "w-spacing\">6</property><property name=\"column-spacing\">12</property>"
  "<child><object class=\"GtkLabel\" id=\"label54\"><property name=\"visib"
  "le\">True</property><property name=\"can-focus\">False</property><prope"
  "rty name=\"halign\">start</property><property name=\"label\" translatab"
  "le=\"yes\">Cursor shape:</property><property name=\"use-underline\">Tru"
  "e</property></object><packing><property name=\"left-attach\">0</propert"
  "y><property name=\"top-attach\">0</property></packing></child><child><o"
  "bject class=\"GtkComboBox\" id=\"misc-cursor-shape\"><property name=\"v"
  "isible\">True</property><property name=\"can-focus\">False</property><p"
  "roperty name=\"hexpand\">True</property><property name=\"model\">listst"
  "ore7</property><child><object class=\"GtkCellRendererText\" id=\"cellre"
  "nderertext9\"/><attributes><attribute name=\"text\">0</attribute></attr"
  "ibutes></child></object><packing><property name=\"left-attach\">1</prop"
  "erty><property name=\"top-attach\">0</property></packing></child><child"
  "><object class=\"GtkCheckButton\" id=\"misc-cursor-blinks\"><property n"
  "ame=\"label\" translatable=\"yes\">Cursor blinks</property><property na"
  "me=\"visible\">True</property><property name=\"can-focus\">True</proper"
  "ty><property name=\"receives-default\">False</property><property name=\""
  "tooltip-text\" translatable=\"yes\">This option controls whether the cu"
  "rsor will be blinking or not.</property><property name=\"halign\">start"
  "</property><property name=\"use-underline\">True</property><property na"
  "me=\"draw-indicator\">True</property></object><packing><property name=\""
  "left-attach\">2</property><property name=\"top-attach\">0</property></p"
  "acking></child><child><placeholder/></child><child><placeholder/></chil"
  "d><child><placeholder/></child><child><placeholder/></child><child><pla"
  "ceholder/></child><child><placeholder/></child></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">True</prope"
  "rty><property name=\"position\">0</property></packing></child></object>"
  "</child></object></child><child type=\"label\"><object class=\"GtkLabel"
  "\" id=\"label53\"><property name=\"visible\">True</property><property n"
  "ame=\"can-focus\">False</property><property name=\"label\" translatable"
  "=\"yes\">Cursor</property><attributes><attribute name=\"weight\" value="
  "\"bold\"/></attributes></object></child></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">3</property></packing></child><child><object c"
  "lass=\"GtkFrame\" id=\"frame14\"><property name=\"visible\">True</prope"
  "rty><property name=\"can-focus\">False</property><property name=\"label"
  "-xalign\">0</property><property name=\"shadow-type\">none</property><ch"
  "ild><object class=\"GtkAlignment\" id=\"alignment7\"><property name=\"v"
  "isible\">True</property><property name=\"can-focus\">False</property><p"
  "roperty name=\"left-padding\">12</property><child><object class=\"GtkBo"
  "x\" id=\"vbox14\"><property name=\"visible\">True</property><property n"
  "ame=\"can-focus\">False</property><property name=\"border-width\">6</pr"
  "operty><property name=\"orientation\">vertical</property><property name"
  "=\"spacing\">6</property><child><object class=\"GtkGrid\" id=\"grid9\">"
  "<property name=\"visible\">True</property><property name=\"can-focus\">"
  "False</property><property name=\"row-spacing\">6</property><property na"
  "me=\"column-spacing\">12</property><child><object class=\"GtkCheckButto"
  "n\" id=\"misc-copy-on-select\"><property name=\"label\" translatable=\""
  "yes\">Automatically _copy selection to clipboard</property><property na"
  "me=\"visible\">True</property><property name=\"can-focus\">True</proper"
  "ty><property name=\"receives-default\">False</property><property name=\""
  "halign\">start</property><property name=\"use-underline\">True</propert"
  "y><property name=\"draw-indicator\">True</property></object><packing><p"
  "roperty name=\"left-attach\">0</property><property name=\"top-attach\">"
  "0</property></packing></child><child><object class=\"GtkCheckButton\" i"
  "d=\"misc-show-unsafe-paste-dialog\"><property name=\"label\" translatab"
  "le=\"yes\">Show unsafe _paste dialog</property><property name=\"visible"
  "\">True</property><property name=\"can-focus\">True</property><property"
  " name=\"receives-default\">False</property><property name=\"tooltip-tex"
  "t\" translatable=\"yes\">Show a dialog that allows to edit text that is"
  " considered unsafe for pasting.</property><property name=\"halign\">sta"
  "rt</property><property name=\"use-underline\">True</property><property "
  "name=\"draw-indicator\">True</property></object><packing><property name"
  "=\"left-attach\">1</property><property name=\"top-attach\">0</property>"
  "</packing></child><child><placeholder/></child><child><placeholder/></c"
  "hild><child><placeholder/></child><child><placeholder/></child><child><"
  "placeholder/></child><child><placeholder/></child><child><placeholder/>"
  "</child></object><packing><property name=\"expand\">False</property><pr"
  "operty name=\"fill\">True</property><property name=\"position\">0</prop"
  "erty></packing></child></object></child></object></child><child type=\""
  "label\"><object class=\"GtkLabel\" id=\"label63\"><property name=\"visi"
  "ble\">True</property><property name=\"can-focus\">False</property><prop"
  "erty name=\"label\" translatable=\"yes\">Clipboard</property><attribute"
  "s><attribute name=\"weight\" value=\"bold\"/></attributes></object></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">4</property"
  "></packing></child></object></child><child type=\"tab\"><object class=\""
  "GtkLabel\" id=\"label1\"><property name=\"visible\">True</property><pro"
  "perty name=\"can-focus\">False</property><property name=\"label\" trans"
  "latable=\"yes\">_General</property><property name=\"use-underline\">Tru"
  "e</property></object><packing><property name=\"tab-fill\">False</proper"
  "ty></packing></child><child><object class=\"GtkBox\" id=\"dropdown-box\""
  "><property name=\"visible\">True</property><property name=\"can-focus\""
  ">False</property><property name=\"border-width\">6</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">6</p"
  "roperty><child><object class=\"GtkFrame\" id=\"frame10\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">False</propert"
  "y><property name=\"label-xalign\">0</property><property name=\"shadow-t"
  "ype\">none</property><child><object class=\"GtkAlignment\" id=\"alignme"
  "nt24\"><property name=\"visible\">True</property><property name=\"can-f"
  "ocus\">False</property><property name=\"left-padding\">12</property><ch"
  "ild><object class=\"GtkBox\" id=\"vbox10\"><property name=\"visible\">T"
  "rue</property><property name=\"can-focus\">False</property><property na"
  "me=\"border-width\">6</property><property name=\"orientation\">vertical"
  "</property><property name=\"spacing\">6</property><child><object class="
  "\"GtkCheckButton\" id=\"dropdown-keep-open-default\"><property name=\"l"
  "abel\" translatable=\"yes\">_Keep window open when it loses focus</prop"
  "erty><property name=\"visible\">True</property><property name=\"can-foc"
  "us\">True</property><property name=\"receives-default\">False</property"
  "><property name=\"halign\">start</property><property name=\"use-underli"
  "ne\">True</property><property name=\"draw-indicator\">True</property></"
  "object><packing><property name=\"expand\">True</property><property name"
  "=\"fill\">True</property><property name=\"position\">0</property></pack"
  "ing></child><child><object class=\"GtkCheckButton\" id=\"dropdown-keep-"
  "above\"><property name=\"label\" translatable=\"yes\">Always keep windo"
  "w on _top</property><property name=\"visible\">True</property><property"
  " name=\"can-focus\">True</property><property name=\"receives-default\">"
  "False</property><property name=\"halign\">start</property><property nam"
  "e=\"use-underline\">True</property><property name=\"draw-indicator\">Tr"
  "ue</property></object><packing><property name=\"expand\">True</property"
  "><property name=\"fill\">True</property><property name=\"position\">1</"
  "property></packing></child><child><object class=\"GtkCheckButton\" id=\""
  "dropdown-toggle-focus\"><property name=\"label\" translatable=\"yes\">U"
  "se shortcut to _focus visible window</property><property name=\"visible"
  "\">True</property><property name=\"can-focus\">True</property><property"
  " name=\"receives-default\">False</property><property name=\"tooltip-tex"
  "t\" translatable=\"yes\">If enabled, the shortcut to open and retract t"
  "he window will give focus, rather than closing it, if it has previously"
  " lost focus</property><property name=\"halign\">start</property><proper"
  "ty name=\"use-underline\">True</property><property name=\"draw-indicato"
  "r\">True</property></object><packing><property name=\"expand\">True</pr"
  "operty><property name=\"fill\">True</property><property name=\"position"
  "\">2</property></packing></child><child><object class=\"GtkCheckButton\""
  " id=\"dropdown-status-icon\"><property name=\"label\" translatable=\"ye"
  "s\">Show _status icon in notification area</property><property name=\"v"
  "isible\">True</property><property name=\"can-focus\">True</property><pr"
  "operty name=\"receives-default\">False</property><property name=\"halig"
  "n\">start</property><property name=\"use-underline\">True</property><pr"
  "operty name=\"draw-indicator\">True</property></object><packing><proper"
  "ty name=\"expand\">True</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">3</property></packing></child></object></"
  "child></object></child><child type=\"label\"><object class=\"GtkLabel\""
  " id=\"label23\"><property name=\"visible\">True</property><property nam"
  "e=\"can-focus\">False</property><property name=\"label\" translatable=\""
  "yes\">Behavior</property><property name=\"use-markup\">True</property><"
  "attributes><attribute name=\"weight\" value=\"bold\"/></attributes></ob"
  "ject></child></object><packing><property name=\"expand\">False</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">0<"
  "/property></packing></child><child><object class=\"GtkFrame\" id=\"fram"
  "e16\"><property name=\"visible\">True</property><property name=\"can-fo"
  "cus\">False</property><property name=\"label-xalign\">0</property><prop"
  "erty name=\"shadow-type\">none</property><child><object class=\"GtkAlig"
  "nment\" id=\"alignment25\"><property name=\"visible\">True</property><p"
  "roperty name=\"can-focus\">False</property><property name=\"left-paddin"
  "g\">12</property><child><object class=\"GtkGrid\" id=\"grid8\"><propert"
  "y name=\"visible\">True</property><property name=\"can-focus\">False</p"
  "roperty><property name=\"margin-left\">12</property><property name=\"ma"
  "rgin-right\">6</property><property name=\"margin-top\">6</property><pro"
  "perty name=\"margin-bottom\">6</property><property name=\"row-spacing\""
  ">2</property><property name=\"column-spacing\">6</property><child><obje"
  "ct class=\"GtkLabel\" id=\"label36\"><property name=\"visible\">True</p"
  "roperty><property name=\"can-focus\">False</property><property name=\"h"
  "align\">start</property><property name=\"label\" translatable=\"yes\">W"
  "i_dth:</property><property name=\"use-underline\">True</property><prope"
  "rty name=\"mnemonic-widget\">scale-width</property></object><packing><p"
  "roperty name=\"left-attach\">0</property><property name=\"top-attach\">"
  "0</property></packing></child><child><object class=\"GtkLabel\" id=\"la"
  "bel39\"><property name=\"visible\">True</property><property name=\"can-"
  "focus\">False</property><property name=\"halign\">start</property><prop"
  "erty name=\"label\" translatable=\"yes\">He_ight:</property><property n"
  "ame=\"use-underline\">True</property><property name=\"mnemonic-widget\""
  ">scale-height</property></object><packing><property name=\"left-attach\""
  ">0</property><property name=\"top-attach\">1</property></packing></chil"
  "d><child><object class=\"GtkScale\" id=\"scale-width\"><property name=\""
  "visible\">True</property><property name=\"can-focus\">True</property><p"
  "roperty name=\"hexpand\">True</property><property name=\"adjustment\">d"
  "ropdown-width</property><property name=\"round-digits\">0</property><pr"
  "operty name=\"digits\">0</property><property name=\"value-pos\">right</"
  "property></object><packing><property name=\"left-attach\">1</property><"
  "property name=\"top-attach\">0</property></packing></child><child><obje"
  "ct class=\"GtkScale\" id=\"scale-height\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can-focus\">True</property><property name"
  "=\"hexpand\">True</property><property name=\"adjustment\">dropdown-heig"
  "ht</property><property name=\"round-digits\">0</property><property name"
  "=\"digits\">0</property><property name=\"value-pos\">right</property></"
  "object><packing><property name=\"left-attach\">1</property><property na"
  "me=\"top-attach\">1</property></packing></child><child><object class=\""
  "GtkLabel\" id=\"label43\"><property name=\"visible\">True</property><pr"
  "operty name=\"can-focus\">False</property><property name=\"halign\">sta"
  "rt</property><property name=\"label\">%</property></object><packing><pr"
  "operty name=\"left-attach\">2</property><property name=\"top-attach\">0"
  "</property></packing></child><child><object class=\"GtkLabel\" id=\"lab"
  "el44\"><property name=\"visible\">True</property><property name=\"can-f"
  "ocus\">False</property><property name=\"halign\">start</property><prope"
  "rty name=\"label\">%</property></object><packing><property name=\"left-"
  "attach\">2</property><property name=\"top-attach\">1</property></packin"
  "g></child><child><object class=\"GtkCheckButton\" id=\"dropdown-always-"
  "show-tabs\"><property name=\"label\" translatable=\"yes\">_Always show "
  "tabs</property><property name=\"visible\">True</property><property name"
  "=\"can-focus\">True</property><property name=\"receives-default\">False"
  "</property><property name=\"halign\">start</property><property name=\"u"
  "se-underline\">True</property><property name=\"draw-indicator\">True</p"
  "roperty></object><packing><property name=\"left-attach\">0</property><p"
  "roperty name=\"top-attach\">5</property><property name=\"width\">3</pro"
  "perty></packing></child><child><object class=\"GtkLabel\" id=\"label41\""
  "><property name=\"visible\">True</property><property name=\"can-focus\""
  ">False</property><property name=\"halign\">start</property><property na"
  "me=\"label\" translatable=\"yes\">D_uration:</property><property name=\""
  "use-underline\">True</property></object><packing><property name=\"left-"
  "attach\">0</property><property name=\"top-attach\">4</property></packin"
  "g></child><child><object class=\"GtkScale\" id=\"scale-duration\"><prop"
  "erty name=\"visible\">True</property><property name=\"can-focus\">True<"
  "/property><property name=\"hexpand\">True</property><property name=\"ad"
  "justment\">dropdown-animation-time</property><property name=\"round-dig"
  "its\">0</property><property name=\"digits\">0</property><property name="
  "\"value-pos\">right</property></object><packing><property name=\"left-a"
  "ttach\">1</property><property name=\"top-attach\">4</property></packing"
  "></child><child><object class=\"GtkLabel\" id=\"label42\"><property nam"
  "e=\"visible\">True</property><property name=\"can-focus\">False</proper"
  "ty><property name=\"halign\">start</property><property name=\"label\" t"
  "ranslatable=\"yes\">ms</property></object><packing><property name=\"lef"
  "t-attach\">2</property><property name=\"top-attach\">4</property></pack"
  "ing></child><child><object class=\"GtkLabel\" id=\"label40\"><property "
  "name=\"visible\">True</property><property name=\"can-focus\">False</pro"
  "perty><property name=\"halign\">start</property><property name=\"label\""
  " translatable=\"yes\">_Opacity:</property><property name=\"use-underlin"
  "e\">True</property></object><packing><property name=\"left-attach\">0</"
  "property><property name=\"top-attach\">3</property></packing></child><c"
  "hild><object class=\"GtkScale\" id=\"scale-opacity\"><property name=\"v"
  "isible\">True</property><property name=\"can-focus\">True</property><pr"
  "operty name=\"hexpand\">True</property><property name=\"adjustment\">dr"
  "opdown-opacity</property><property name=\"round-digits\">0</property><p"
  "roperty name=\"digits\">0</property><property name=\"value-pos\">right<"
  "/property></object><packing><property name=\"left-attach\">1</property>"
  "<property name=\"top-attach\">3</property></packing></child><child><obj"
  "ect class=\"GtkLabel\" id=\"label45\"><property name=\"visible\">True</"
  "property><property name=\"can-focus\">False</property><property name=\""
  "halign\">start</property><property name=\"label\">%</property></object>"
  "<packing><property name=\"left-attach\">2</property><property name=\"to"
  "p-attach\">3</property></packing></child><child><object class=\"GtkLabe"
  "l\" id=\"dropdown-opacity-not-available\"><property name=\"can-focus\">"
  "False</property><property name=\"label\" translatable=\"yes\">Opacity s"
  "etting is not available since compositing is either disabled\nor not su"
  "pported by your Window Manager.</property><property name=\"justify\">ce"
  "nter</property><attributes><attribute name=\"foreground\" value=\"#efef"
  "29292929\"/></attributes></object><packing><property name=\"left-attach"
  "\">0</property><property name=\"top-attach\">2</property><property name"
  "=\"width\">3</property></packing></child><child><object class=\"GtkChec"
  "kButton\" id=\"dropdown-show-borders\"><property name=\"label\" transla"
  "table=\"yes\">Show window _borders</property><property name=\"visible\""
  ">True</property><property name=\"can-focus\">True</property><property n"
  "ame=\"receives-default\">False</property><property name=\"halign\">star"
  "t</property><property name=\"use-underline\">True</property><property n"
  "ame=\"draw-indicator\">True</property></object><packing><property name="
  "\"left-attach\">0</property><property name=\"top-attach\">6</property><"
  "property name=\"width\">3</property></packing></child></object></child>"
  "</object></child><child type=\"label\"><object class=\"GtkLabel\" id=\""
  "label46\"><property name=\"visible\">True</property><property name=\"ca"
  "n-focus\">False</property><property name=\"label\" translatable=\"yes\""
  ">Appearance and Animation</property><property name=\"use-markup\">True<"
  "/property><attributes><attribute name=\"weight\" value=\"bold\"/></attr"
  "ibutes></object></child></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">1</property></packing></child><child><object class=\"GtkFrame\""
  " id=\"frame17\"><property name=\"visible\">True</property><property nam"
  "e=\"can-focus\">False</property><property name=\"label-xalign\">0</prop"
  "erty><property name=\"shadow-type\">none</property><child><object class"
  "=\"GtkAlignment\" id=\"alignment26\"><property name=\"visible\">True</p"
  "roperty><property name=\"can-focus\">False</property><property name=\"l"
  "eft-padding\">18</property><child><object class=\"GtkBox\" id=\"vbox15\""
  "><property name=\"visible\">True</property><property name=\"can-focus\""
  ">False</property><property name=\"border-width\">6</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">6</p"
  "roperty><child><object class=\"GtkBox\" id=\"hbox2\"><property name=\"v"
  "isible\">True</property><property name=\"can-focus\">False</property><p"
  "roperty name=\"spacing\">6</property><child><object class=\"GtkLabel\" "
  "id=\"label47\"><property name=\"visible\">True</property><property name"
  "=\"can-focus\">False</property><property name=\"halign\">start</propert"
  "y><property name=\"label\" translatable=\"yes\">L_eft</property><proper"
  "ty name=\"use-underline\">True</property><property name=\"mnemonic-widg"
  "et\">scale-position</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "Scale\" id=\"scale-position\"><property name=\"visible\">True</property"
  "><property name=\"can-focus\">True</property><property name=\"adjustmen"
  "t\">dropdown-position</property><property name=\"show-fill-level\">True"
  "</property><property name=\"digits\">0</property><property name=\"draw-"
  "value\">False</property></object><packing><property name=\"expand\">Tru"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">1</property></packing></child><child><object class=\"GtkLabel\""
  " id=\"label48\"><property name=\"visible\">True</property><property nam"
  "e=\"can-focus\">False</property><property name=\"halign\">end</property"
  "><property name=\"label\" translatable=\"yes\">Right</property></object"
  "><packing><property name=\"expand\">False</property><property name=\"fi"
  "ll\">True</property><property name=\"position\">2</property></packing><"
  "/child></object><packing><property name=\"expand\">True</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">0</proper"
  "ty></packing></child><child><object class=\"GtkBox\" id=\"hbox9\"><prop"
  "erty name=\"visible\">True</property><property name=\"can-focus\">False"
  "</property><property name=\"spacing\">6</property><child><object class="
  "\"GtkLabel\" id=\"label57\"><property name=\"visible\">True</property><"
  "property name=\"can-focus\">False</property><property name=\"halign\">s"
  "tart</property><property name=\"label\" translatable=\"yes\">U_p</prope"
  "rty><property name=\"use-underline\">True</property><property name=\"mn"
  "emonic-widget\">scale-position1</property></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">True</property><"
  "property name=\"position\">0</property></packing></child><child><object"
  " class=\"GtkScale\" id=\"scale-position1\"><property name=\"visible\">T"
  "rue</property><property name=\"can-focus\">True</property><property nam"
  "e=\"adjustment\">dropdown-position-vertical</property><property name=\""
  "show-fill-level\">True</property><property name=\"digits\">0</property>"
  "<property name=\"draw-value\">False</property></object><packing><proper"
  "ty name=\"expand\">True</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">1</property></packing></child><child><obj"
  "ect class=\"GtkLabel\" id=\"label58\"><property name=\"visible\">True</"
  "property><property name=\"can-focus\">False</property><property name=\""
  "halign\">end</property><property name=\"label\" translatable=\"yes\">Do"
  "wn</property></object><packing><property name=\"expand\">False</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">2<"
  "/property></packing></child></object><packing><property name=\"expand\""
  ">True</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child><child><object class=\"GtkChec"
  "kButton\" id=\"dropdown-move-to-active\"><property name=\"label\" trans"
  "latable=\"yes\">Move to monitor with poi_nter</property><property name="
  "\"visible\">True</property><property name=\"can-focus\">True</property>"
  "<property name=\"receives-default\">False</property><property name=\"ha"
  "lign\">start</property><property name=\"use-underline\">True</property>"
  "<property name=\"draw-indicator\">True</property></object><packing><pro"
  "perty name=\"expand\">True</property><property name=\"fill\">True</prop"
  "erty><property name=\"position\">2</property></packing></child></object"
  "></child></object></child><child type=\"label\"><object class=\"GtkLabe"
  "l\" id=\"label49\"><property name=\"visible\">True</property><property "
  "name=\"can-focus\">False</property><property name=\"label\" translatabl"
  "e=\"yes\">Position</property><property name=\"use-markup\">True</proper"
  "ty><attributes><attribute name=\"weight\" value=\"bold\"/></attributes>"
  "</object></child></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">True</property><property name=\"position\""
  ">2</property></packing></child></object><packing><property name=\"posit"
  "ion\">1</property></packing></child><child type=\"tab\"><object class=\""
  "GtkLabel\" id=\"label20\"><property name=\"visible\">True</property><pr"
  "operty name=\"can-focus\">False</property><property name=\"label\" tran"
  "slatable=\"yes\">Drop-do_wn</property><property name=\"use-underline\">"
  "True</property></object><packing><property name=\"position\">1</propert"
  "y><property name=\"tab-fill\">False</property></packing></child><child>"
  "<object class=\"GtkBox\" id=\"vbox4\"><property name=\"visible\">True</"
  "property><property name=\"can-focus\">False</property><property name=\""
  "border-width\">6</property><property name=\"orientation\">vertical</pro"
  "perty><property name=\"spacing\">6</property><child><object class=\"Gtk"
  "Frame\" id=\"frame4\"><property name=\"visible\">True</property><proper"
  "ty name=\"can-focus\">False</property><property name=\"label-xalign\">0"
  "</property><property name=\"shadow-type\">none</property><child><object"
  " class=\"GtkAlignment\" id=\"alignment4\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can-focus\">False</property><property nam"
  "e=\"border-width\">6</property><property name=\"left-padding\">12</prop"
  "erty><child><object class=\"GtkBox\" id=\"vbox5\"><property name=\"visi"
  "ble\">True</property><property name=\"can-focus\">False</property><prop"
  "erty name=\"orientation\">vertical</property><property name=\"spacing\""
  ">6</property><child><object class=\"GtkBox\" id=\"hbox13\"><property na"
  "me=\"visible\">True</property><property name=\"can-focus\">False</prope"
  "rty><property name=\"spacing\">12</property><child><object class=\"GtkC"
  "heckButton\" id=\"font-use-system\"><property name=\"label\" translatab"
  "le=\"yes\">Use system _font</property><property name=\"visible\">True</"
  "property><property name=\"can-focus\">True</property><property name=\"r"
  "eceives-default\">False</property><property name=\"tooltip-text\" trans"
  "latable=\"yes\">Enable this option to use system-wide monospace font.</"
  "property><property name=\"halign\">start</property><property name=\"use"
  "-underline\">True</property><property name=\"draw-indicator\">True</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">0</proper"
  "ty></packing></child><child><object class=\"GtkFontButton\" id=\"font-n"
  "ame\"><property name=\"use-action-appearance\">False</property><propert"
  "y name=\"visible\">True</property><property name=\"can-focus\">True</pr"
  "operty><property name=\"receives-default\">True</property><property nam"
  "e=\"font\">Sans 12</property><property name=\"title\" translatable=\"ye"
  "s\">Choose Terminal Font</property><property name=\"use-font\">True</pr"
  "operty></object><packing><property name=\"expand\">True</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">1</proper"
  "ty></packing></child></object><packing><property name=\"expand\">False<"
  "/property><property name=\"fill\">True</property><property name=\"posit"
  "ion\">0</property></packing></child><child><object class=\"GtkCheckButt"
  "on\" id=\"font-allow-bold\"><property name=\"label\" translatable=\"yes"
  "\">Allow bold te_xt</property><property name=\"visible\">True</property"
  "><property name=\"can-focus\">True</property><property name=\"receives-"
  "default\">False</property><property name=\"tooltip-text\" translatable="
  "\"yes\">Enable this option to allow applications running inside the ter"
  "minal windows to use bold text.</property><property name=\"halign\">sta"
  "rt</property><property name=\"use-underline\">True</property><property "
  "name=\"draw-indicator\">True</property></object><packing><property name"
  "=\"expand\">True</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">1</property></packing></child><child><object cla"
  "ss=\"GtkBox\" id=\"box-text-blink\"><property name=\"visible\">True</pr"
  "operty><property name=\"can-focus\">False</property><property name=\"to"
  "oltip-text\" translatable=\"yes\">Controls whether text in the terminal"
  " is allowed to blink when \'\\e[5m\' escape codes are used.</property><"
  "property name=\"spacing\">12</property><child><object class=\"GtkLabel\""
  " id=\"text-blink-label\"><property name=\"visible\">True</property><pro"
  "perty name=\"can-focus\">False</property><property name=\"label\" trans"
  "latable=\"yes\">Text blinks:</property><property name=\"use-underline\""
  ">True</property><property name=\"mnemonic-widget\">trans-scale</propert"
  "y></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">True</property><property name=\"position\">0</property><"
  "/packing></child><child><object class=\"GtkComboBox\" id=\"text-blink-m"
  "ode\"><property name=\"visible\">True</property><property name=\"can-fo"
  "cus\">False</property><property name=\"model\">liststore9</property><ch"
  "ild><object class=\"GtkCellRendererText\" id=\"cellrenderertext11\"/><a"
  "ttributes><attribute name=\"text\">0</attribute></attributes></child></"
  "object><packing><property name=\"expand\">True</property><property name"
  "=\"fill\">True</property><property name=\"position\">1</property></pack"
  "ing></child></object><packing><property name=\"expand\">True</property>"
  "<property name=\"fill\">True</property><property name=\"position\">2</p"
  "roperty></packing></child><child><object class=\"GtkBox\" id=\"cell-sp-"
  "box\"><property name=\"visible\">True</property><property name=\"can-fo"
  "cus\">False</property><property name=\"spacing\">12</property><child><o"
  "bject class=\"GtkLabel\" id=\"label27\"><property name=\"visible\">True"
  "</property><property name=\"can-focus\">False</property><property name="
  "\"label\" translatable=\"yes\">Cell spacing:</property></object><packin"
  "g><property name=\"expand\">False</property><property name=\"fill\">Tru"
  "e</property><property name=\"position\">0</property></packing></child><"
  "child><object class=\"GtkBox\" id=\"hbox11\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">False</property><property "
  "name=\"spacing\">6</property><child><object class=\"GtkSpinButton\" id="
  "\"spin-cell-width-scale\"><property name=\"visible\">True</property><pr"
  "operty name=\"can-focus\">True</property><property name=\"adjustment\">"
  "cell-width-scale</property><property name=\"digits\">2</property></obje"
  "ct><packing><property name=\"expand\">True</property><property name=\"f"
  "ill\">True</property><property name=\"position\">0</property></packing>"
  "</child><child><object class=\"GtkLabel\" id=\"label59\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">False</propert"
  "y><property name=\"label\" translatable=\"yes\">x width</property><prop"
  "erty name=\"use-underline\">True</property><property name=\"mnemonic-wi"
  "dget\">spin-columns</property></object><packing><property name=\"expand"
  "\">True</property><property name=\"fill\">True</property><property name"
  "=\"position\">1</property></packing></child></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">1</property></packing></child><child><obje"
  "ct class=\"GtkBox\" id=\"hbox12\"><property name=\"visible\">True</prop"
  "erty><property name=\"can-focus\">False</property><property name=\"spac"
  "ing\">6</property><child><object class=\"GtkSpinButton\" id=\"spin-cell"
  "-height-scale\"><property name=\"visible\">True</property><property nam"
  "e=\"can-focus\">True</property><property name=\"adjustment\">cell-heigh"
  "t-scale</property><property name=\"digits\">2</property></object><packi"
  "ng><property name=\"expand\">True</property><property name=\"fill\">Tru"
  "e</property><property name=\"position\">0</property></packing></child><"
  "child><object class=\"GtkLabel\" id=\"label60\"><property name=\"visibl"
  "e\">True</property><property name=\"can-focus\">False</property><proper"
  "ty name=\"label\" translatable=\"yes\">x height</property><property nam"
  "e=\"use-underline\">True</property><property name=\"mnemonic-widget\">s"
  "pin-rows</property></object><packing><property name=\"expand\">True</pr"
  "operty><property name=\"fill\">True</property><property name=\"position"
  "\">1</property></packing></child></object><packing><property name=\"exp"
  "and\">False</property><property name=\"fill\">True</property><property "
  "name=\"position\">2</property></packing></child><child><object class=\""
  "GtkButton\" id=\"reset-cell-scale\"><property name=\"label\" translatab"
  "le=\"yes\">Rese_t</property><property name=\"visible\">True</property><"
  "property name=\"can-focus\">True</property><property name=\"receives-de"
  "fault\">True</property><property name=\"tooltip-text\" translatable=\"y"
  "es\">Reset cell spacing values to defaults</property><property name=\"v"
  "align\">center</property><property name=\"use-underline\">True</propert"
  "y></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">True</property><property name=\"position\">3</property><"
  "/packing></child></object><packing><property name=\"expand\">True</prop"
  "erty><property name=\"fill\">True</property><property name=\"position\""
  ">3</property></packing></child></object></child></object></child><child"
  " type=\"label\"><object class=\"GtkLabel\" id=\"label11\"><property nam"
  "e=\"visible\">True</property><property name=\"can-focus\">False</proper"
  "ty><property name=\"label\" translatable=\"yes\">Font</property><proper"
  "ty name=\"use-markup\">True</property><attributes><attribute name=\"wei"
  "ght\" value=\"bold\"/></attributes></object></child></object><packing><"
  "property name=\"expand\">False</property><property name=\"fill\">True</"
  "property><property name=\"position\">0</property></packing></child><chi"
  "ld><object class=\"GtkFrame\" id=\"frame5\"><property name=\"visible\">"
  "True</property><property name=\"can-focus\">False</property><property n"
  "ame=\"label-xalign\">0</property><property name=\"shadow-type\">none</p"
  "roperty><child><object class=\"GtkAlignment\" id=\"alignment5\"><proper"
  "ty name=\"visible\">True</property><property name=\"can-focus\">False</"
  "property><property name=\"left-padding\">12</property><child><object cl"
  "ass=\"GtkBox\" id=\"vbox6\"><property name=\"visible\">True</property><"
  "property name=\"can-focus\">False</property><property name=\"border-wid"
  "th\">6</property><property name=\"orientation\">vertical</property><pro"
  "perty name=\"spacing\">6</property><child><object class=\"GtkComboBox\""
  " id=\"background-mode\"><property name=\"visible\">True</property><prop"
  "erty name=\"can-focus\">False</property><property name=\"model\">listst"
  "ore3</property><child><object class=\"GtkCellRendererText\" id=\"cellre"
  "nderertext3\"/><attributes><attribute name=\"text\">0</attribute></attr"
  "ibutes></child></object><packing><property name=\"expand\">True</proper"
  "ty><property name=\"fill\">True</property><property name=\"position\">0"
  "</property></packing></child><child><object class=\"GtkTable\" id=\"box"
  "-file\"><property name=\"visible\">True</property><property name=\"can-"
  "focus\">False</property><property name=\"n-rows\">2</property><property"
  " name=\"n-columns\">2</property><property name=\"column-spacing\">12</p"
  "roperty><property name=\"row-spacing\">6</property><child><object class"
  "=\"GtkLabel\" id=\"file-label\"><property name=\"visible\">True</proper"
  "ty><property name=\"can-focus\">False</property><property name=\"label\""
  " translatable=\"yes\">_File:</property><property name=\"use-underline\""
  ">True</property><property name=\"mnemonic-widget\">background-image-fil"
  "e</property></object><packing><property name=\"x-options\">GTK_FILL</pr"
  "operty></packing></child><child><object class=\"GtkLabel\" id=\"style-l"
  "abel\"><property name=\"visible\">True</property><property name=\"can-f"
  "ocus\">False</property><property name=\"label\" translatable=\"yes\">St"
  "_yle:</property><property name=\"use-underline\">True</property><proper"
  "ty name=\"mnemonic-widget\">background-image-style</property></object><"
  "packing><property name=\"top-attach\">1</property><property name=\"bott"
  "om-attach\">2</property><property name=\"x-options\">GTK_FILL</property"
  "></packing></child><child><object class=\"GtkComboBox\" id=\"background"
  "-image-style\"><property name=\"visible\">True</property><property name"
  "=\"can-focus\">False</property><property name=\"model\">liststore6</pro"
  "perty><child><object class=\"GtkCellRendererText\" id=\"cellrenderertex"
  "t6\"/><attributes><attribute name=\"text\">0</attribute></attributes></"
  "child></object><packing><property name=\"left-attach\">1</property><pro"
  "perty name=\"right-attach\">2</property><property name=\"top-attach\">1"
  "</property><property name=\"bottom-attach\">2</property></packing></chi"
  "ld><child><object class=\"GtkFileChooserButton\" id=\"background-image-"
  "file\"><property name=\"visible\">True</property><property name=\"can-f"
  "ocus\">False</property><property name=\"title\" translatable=\"yes\">Se"
  "lect Background Image File</property></object><packing><property name=\""
  "left-attach\">1</property><property name=\"right-attach\">2</property><"
  "/packing></child></object><packing><property name=\"expand\">True</prop"
  "erty><property name=\"fill\">True</property><property name=\"position\""
  ">1</property></packing></child><child><object class=\"GtkLabel\" id=\"l"
  "abel-opacity-not-available\"><property name=\"can-focus\">False</proper"
  "ty><property name=\"label\" translatable=\"yes\">Opacity setting is not"
  " available since compositing is either disabled\nor not supported by yo"
  "ur Window Manager.</property><property name=\"justify\">center</propert"
  "y><attributes><attribute name=\"foreground\" value=\"#efef29292929\"/><"
  "/attributes></object><packing><property name=\"expand\">False</property"
  "><property name=\"fill\">True</property><property name=\"position\">2</"
  "property></packing></child><child><object class=\"GtkBox\" id=\"box-opa"
  "city\"><property name=\"visible\">True</property><property name=\"can-f"
  "ocus\">False</property><property name=\"spacing\">12</property><child><"
  "object class=\"GtkLabel\" id=\"opacity-label\"><property name=\"visible"
  "\">True</property><property name=\"can-focus\">False</property><propert"
  "y name=\"label\" translatable=\"yes\">_Opacity:</property><property nam"
  "e=\"use-underline\">True</property><property name=\"mnemonic-widget\">t"
  "rans-scale</property></object><packing><property name=\"expand\">False<"
  "/property><property name=\"fill\">True</property><property name=\"posit"
  "ion\">0</property></packing></child><child><object class=\"GtkScale\" i"
  "d=\"trans-scale\"><property name=\"visible\">True</property><property n"
  "ame=\"can-focus\">True</property><property name=\"adjustment\">backgrou"
  "nd-darkness</property><property name=\"round-digits\">2</property><prop"
  "erty name=\"digits\">2</property><property name=\"value-pos\">right</pr"
  "operty></object><packing><property name=\"expand\">True</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">1</proper"
  "ty></packing></child></object><packing><property name=\"expand\">True</"
  "property><property name=\"fill\">True</property><property name=\"positi"
  "on\">3</property></packing></child><child><object class=\"GtkBox\" id=\""
  "box-shading\"><property name=\"visible\">True</property><property name="
  "\"can-focus\">False</property><property name=\"spacing\">12</property><"
  "child><object class=\"GtkLabel\" id=\"shading-label\"><property name=\""
  "visible\">True</property><property name=\"can-focus\">False</property><"
  "property name=\"label\" translatable=\"yes\">_Shading:</property><prope"
  "rty name=\"use-underline\">True</property><property name=\"mnemonic-wid"
  "get\">shading-scale</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "Scale\" id=\"shading-scale\"><property name=\"visible\">True</property>"
  "<property name=\"can-focus\">True</property><property name=\"adjustment"
  "\">background-image-shading</property><property name=\"round-digits\">2"
  "</property><property name=\"digits\">2</property><property name=\"value"
  "-pos\">right</property></object><packing><property name=\"expand\">True"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">1</property></packing></child></object><packing><property name=\""
  "expand\">True</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">4</property></packing></child></object></child></ob"
  "ject></child><child type=\"label\"><object class=\"GtkLabel\" id=\"labe"
  "l12\"><property name=\"visible\">True</property><property name=\"can-fo"
  "cus\">False</property><property name=\"label\" translatable=\"yes\">Bac"
  "kground</property><property name=\"use-markup\">True</property><attribu"
  "tes><attribute name=\"weight\" value=\"bold\"/></attributes></object></"
  "child></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">1</proper"
  "ty></packing></child><child><object class=\"GtkFrame\" id=\"frame6\"><p"
  "roperty name=\"visible\">True</property><property name=\"can-focus\">Fa"
  "lse</property><property name=\"label-xalign\">0</property><property nam"
  "e=\"shadow-type\">none</property><child><object class=\"GtkAlignment\" "
  "id=\"alignment6\"><property name=\"visible\">True</property><property n"
  "ame=\"can-focus\">False</property><property name=\"left-padding\">12</p"
  "roperty><child><object class=\"GtkBox\" id=\"vbox7\"><property name=\"v"
  "isible\">True</property><property name=\"can-focus\">False</property><p"
  "roperty name=\"border-width\">6</property><property name=\"orientation\""
  ">vertical</property><property name=\"spacing\">6</property><child><obje"
  "ct class=\"GtkCheckButton\" id=\"misc-menubar-default\"><property name="
  "\"label\" translatable=\"yes\">Display _menubar in new windows</propert"
  "y><property name=\"visible\">True</property><property name=\"can-focus\""
  ">True</property><property name=\"receives-default\">False</property><pr"
  "operty name=\"tooltip-text\" translatable=\"yes\">Enable this option to"
  " show the menubar in newly created terminal windows.</property><propert"
  "y name=\"halign\">start</property><property name=\"use-underline\">True"
  "</property><property name=\"draw-indicator\">True</property></object><p"
  "acking><property name=\"expand\">True</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkCheckButton\" id=\"misc-toolbar-default\">"
  "<property name=\"label\" translatable=\"yes\">Display _toolbar in new w"
  "indows</property><property name=\"visible\">True</property><property na"
  "me=\"can-focus\">True</property><property name=\"receives-default\">Fal"
  "se</property><property name=\"tooltip-text\" translatable=\"yes\">Enabl"
  "e this option to show the toolbar in newly created terminal windows.</p"
  "roperty><property name=\"halign\">start</property><property name=\"use-"
  "underline\">True</property><property name=\"draw-indicator\">True</prop"
  "erty></object><packing><property name=\"expand\">True</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">1</property"
  "></packing></child><child><object class=\"GtkCheckButton\" id=\"misc-bo"
  "rders-default\"><property name=\"label\" translatable=\"yes\">Display _"
  "borders around new windows</property><property name=\"visible\">True</p"
  "roperty><property name=\"can-focus\">True</property><property name=\"re"
  "ceives-default\">False</property><property name=\"tooltip-text\" transl"
  "atable=\"yes\">Enable this option to show window decorations around new"
  "ly created terminal windows.</property><property name=\"halign\">start<"
  "/property><property name=\"use-underline\">True</property><property nam"
  "e=\"draw-indicator\">True</property></object><packing><property name=\""
  "expand\">True</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">2</property></packing></child><child><object class="
  "\"GtkBox\" id=\"geo-box\"><property name=\"visible\">True</property><pr"
  "operty name=\"can-focus\">False</property><property name=\"spacing\">12"
  "</property><child><object class=\"GtkLabel\" id=\"label50\"><property n"
  "ame=\"visible\">True</property><property name=\"can-focus\">False</prop"
  "erty><property name=\"label\" translatable=\"yes\">Default geometry:</p"
  "roperty></object><packing><property name=\"expand\">False</property><pr"
  "operty name=\"fill\">True</property><property name=\"position\">0</prop"
  "erty></packing></child><child><object class=\"GtkBox\" id=\"hbox6\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Fal"
  "se</property><property name=\"spacing\">6</property><child><object clas"
  "s=\"GtkSpinButton\" id=\"spin-columns\"><property name=\"visible\">True"
  "</property><property name=\"can-focus\">True</property><property name=\""
  "invisible-char\">\342\227\217</property><property name=\"width-chars\">"
  "5</property><property name=\"primary-icon-activatable\">False</property"
  "><property name=\"secondary-icon-activatable\">False</property><propert"
  "y name=\"adjustment\">geo-columns</property></object><packing><property"
  " name=\"expand\">True</property><property name=\"fill\">True</property>"
  "<property name=\"position\">0</property></packing></child><child><objec"
  "t class=\"GtkLabel\" id=\"label51\"><property name=\"visible\">True</pr"
  "operty><property name=\"can-focus\">False</property><property name=\"la"
  "bel\" translatable=\"yes\">c_olumns</property><property name=\"use-unde"
  "rline\">True</property><property name=\"mnemonic-widget\">spin-columns<"
  "/property></object><packing><property name=\"expand\">True</property><p"
  "roperty name=\"fill\">True</property><property name=\"position\">1</pro"
  "perty></packing></child></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">1</property></packing></child><child><object class=\"GtkBox\" "
  "id=\"hbox7\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">False</property><property name=\"spacing\">6</property><chi"
  "ld><object class=\"GtkSpinButton\" id=\"spin-rows\"><property name=\"vi"
  "sible\">True</property><property name=\"can-focus\">True</property><pro"
  "perty name=\"invisible-char\">\342\227\217</property><property name=\"w"
  "idth-chars\">5</property><property name=\"primary-icon-activatable\">Fa"
  "lse</property><property name=\"secondary-icon-activatable\">False</prop"
  "erty><property name=\"adjustment\">geo-rows</property></object><packing"
  "><property name=\"expand\">True</property><property name=\"fill\">True<"
  "/property><property name=\"position\">0</property></packing></child><ch"
  "ild><object class=\"GtkLabel\" id=\"label52\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">row_s</property><property name=\"us"
  "e-underline\">True</property><property name=\"mnemonic-widget\">spin-ro"
  "ws</property></object><packing><property name=\"expand\">True</property"
  "><property name=\"fill\">True</property><property name=\"position\">1</"
  "property></packing></child></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">2</property></packing></child></object><packing><property na"
  "me=\"expand\">True</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">3</property></packing></child></object></child"
  "></object></child><child type=\"label\"><object class=\"GtkLabel\" id=\""
  "label13\"><property name=\"visible\">True</property><property name=\"ca"
  "n-focus\">False</property><property name=\"label\" translatable=\"yes\""
  ">Opening New Windows</property><property name=\"use-markup\">True</prop"
  "erty><attributes><attribute name=\"weight\" value=\"bold\"/></attribute"
  "s></object></child></object><packing><property name=\"expand\">False</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">2</property></packing></child><child><object class=\"GtkFrame\" id="
  "\"frame20\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">False</property><property name=\"label-xalign\">0</property"
  "><property name=\"shadow-type\">none</property><child><object class=\"G"
  "tkAlignment\" id=\"alignment1\"><property name=\"visible\">True</proper"
  "ty><property name=\"can-focus\">False</property><property name=\"left-p"
  "adding\">12</property><child><object class=\"GtkBox\" id=\"vbox9\"><pro"
  "perty name=\"visible\">True</property><property name=\"can-focus\">Fals"
  "e</property><property name=\"border-width\">6</property><property name="
  "\"orientation\">vertical</property><property name=\"spacing\">6</proper"
  "ty><child><object class=\"GtkBox\" id=\"hbox4\"><property name=\"visibl"
  "e\">True</property><property name=\"can-focus\">False</property><proper"
  "ty name=\"spacing\">12</property><child><object class=\"GtkLabel\" id=\""
  "label28\"><property name=\"visible\">True</property><property name=\"ca"
  "n-focus\">False</property><property name=\"label\" translatable=\"yes\""
  ">Reset tab activity _indicator after</property><property name=\"use-und"
  "erline\">True</property><property name=\"mnemonic-widget\">spinbutton2<"
  "/property></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">True</property><property name=\"position\">0</pr"
  "operty></packing></child><child><object class=\"GtkSpinButton\" id=\"sp"
  "inbutton2\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">True</property><property name=\"invisible-char\">\342\200\242"
  "</property><property name=\"primary-icon-activatable\">False</property>"
  "<property name=\"secondary-icon-activatable\">False</property><property"
  " name=\"adjustment\">tab-activity-timeout</property><property name=\"nu"
  "meric\">True</property><property name=\"update-policy\">if-valid</prope"
  "rty></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">1</property"
  "></packing></child><child><object class=\"GtkLabel\" id=\"label29\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Fal"
  "se</property><property name=\"label\" translatable=\"yes\">seconds</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">False</property><property name=\"position\">2</prope"
  "rty></packing></child></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">0</property></packing></child><child><object class=\"GtkCheckBut"
  "ton\" id=\"misc-slim-tabs\"><property name=\"label\" translatable=\"yes"
  "\">Use custom styling to make tabs _slim (restart required)</property><"
  "property name=\"visible\">True</property><property name=\"can-focus\">T"
  "rue</property><property name=\"receives-default\">False</property><prop"
  "erty name=\"halign\">start</property><property name=\"use-underline\">T"
  "rue</property><property name=\"draw-indicator\">True</property></object"
  "><packing><property name=\"expand\">True</property><property name=\"fil"
  "l\">True</property><property name=\"position\">1</property></packing></"
  "child></object></child></object></child><child type=\"label\"><object c"
  "lass=\"GtkLabel\" id=\"label61\"><property name=\"visible\">True</prope"
  "rty><property name=\"can-focus\">False</property><property name=\"label"
  "\" translatable=\"yes\">Tabs</property><property name=\"use-markup\">Tr"
  "ue</property><attributes><attribute name=\"weight\" value=\"bold\"/></a"
  "ttributes></object></child></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">3</property></packing></child></object><packing><property na"
  "me=\"position\">2</property></packing></child><child type=\"tab\"><obje"
  "ct class=\"GtkLabel\" id=\"label2\"><property name=\"visible\">True</pr"
  "operty><property name=\"can-focus\">False</property><property name=\"la"
  "bel\" translatable=\"yes\">_Appearance</property><property name=\"use-u"
  "nderline\">True</property></object><packing><property name=\"position\""
  ">2</property><property name=\"tab-fill\">False</property></packing></ch"
  "ild><child><object class=\"GtkBox\" id=\"vbox8\"><property name=\"visib"
  "le\">True</property><property name=\"can-focus\">False</property><prope"
  "rty name=\"border-width\">6</property><property name=\"orientation\">ve"
  "rtical</property><property name=\"spacing\">6</property><child><object "
  "class=\"GtkFrame\" id=\"frame7\"><property name=\"visible\">True</prope"
  "rty><property name=\"can-focus\">False</property><property name=\"label"
  "-xalign\">0</property><property name=\"shadow-type\">none</property><ch"
  "ild><object class=\"GtkGrid\" id=\"grid5\"><property name=\"visible\">T"
  "rue</property><property name=\"can-focus\">False</property><property na"
  "me=\"halign\">start</property><property name=\"margin-left\">18</proper"
  "ty><property name=\"margin-right\">12</property><property name=\"margin"
  "-top\">6</property><property name=\"margin-bottom\">6</property><proper"
  "ty name=\"row-spacing\">6</property><property name=\"column-spacing\">1"
  "2</property><child><object class=\"GtkLabel\" id=\"label15\"><property "
  "name=\"visible\">True</property><property name=\"can-focus\">False</pro"
  "perty><property name=\"halign\">start</property><property name=\"label\""
  " translatable=\"yes\">_Text color:</property><property name=\"use-under"
  "line\">True</property></object><packing><property name=\"left-attach\">"
  "0</property><property name=\"top-attach\">1</property></packing></child"
  "><child><object class=\"GtkColorButton\" id=\"color-foreground\"><prope"
  "rty name=\"use-action-appearance\">False</property><property name=\"vis"
  "ible\">True</property><property name=\"can-focus\">True</property><prop"
  "erty name=\"receives-default\">True</property><property name=\"margin-r"
  "ight\">24</property><property name=\"title\" translatable=\"yes\">Choos"
  "e text color</property><property name=\"rgba\">rgb(0,0,0)</property><ch"
  "ild internal-child=\"accessible\"><object class=\"AtkObject\" id=\"colo"
  "r-foreground-atkobject\"><property name=\"AtkObject::accessible-name\" "
  "translatable=\"yes\">Color Selector</property><property name=\"AtkObjec"
  "t::accessible-description\" translatable=\"yes\">Open a dialog to speci"
  "fy the color</property></object></child></object><packing><property nam"
  "e=\"left-attach\">1</property><property name=\"top-attach\">1</property"
  "></packing></child><child><object class=\"GtkLabel\" id=\"label38\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Fal"
  "se</property><property name=\"halign\">start</property><property name=\""
  "label\" translatable=\"yes\">_Background color:</property><property nam"
  "e=\"use-underline\">True</property></object><packing><property name=\"l"
  "eft-attach\">2</property><property name=\"top-attach\">1</property></pa"
  "cking></child><child><object class=\"GtkColorButton\" id=\"color-backgr"
  "ound\"><property name=\"use-action-appearance\">False</property><proper"
  "ty name=\"visible\">True</property><property name=\"can-focus\">True</p"
  "roperty><property name=\"receives-default\">True</property><property na"
  "me=\"margin-right\">24</property><property name=\"title\" translatable="
  "\"yes\">Choose background color</property><property name=\"rgba\">rgb(0"
  ",0,0)</property><child internal-child=\"accessible\"><object class=\"At"
  "kObject\" id=\"color-background-atkobject\"><property name=\"AtkObject:"
  ":accessible-name\" translatable=\"yes\">Color Selector</property><prope"
  "rty name=\"AtkObject::accessible-description\" translatable=\"yes\">Ope"
  "n a dialog to specify the color</property></object></child></object><pa"
  "cking><property name=\"left-attach\">3</property><property name=\"top-a"
  "ttach\">1</property></packing></child><child><object class=\"GtkLabel\""
  " id=\"label35\"><property name=\"visible\">True</property><property nam"
  "e=\"can-focus\">False</property><property name=\"halign\">start</proper"
  "ty><property name=\"label\" translatable=\"yes\">Note: Ctrl+click for c"
  "olor editor.</property></object><packing><property name=\"left-attach\""
  ">0</property><property name=\"top-attach\">0</property><property name=\""
  "width\">6</property></packing></child><child><object class=\"GtkLabel\""
  " id=\"label37\"><property name=\"visible\">True</property><property nam"
  "e=\"can-focus\">False</property><property name=\"halign\">start</proper"
  "ty><property name=\"label\" translatable=\"yes\">Tab activit_y color:</"
  "property><property name=\"use-underline\">True</property></object><pack"
  "ing><property name=\"left-attach\">4</property><property name=\"top-att"
  "ach\">1</property></packing></child><child><object class=\"GtkColorButt"
  "on\" id=\"tab-activity-color\"><property name=\"use-action-appearance\""
  ">False</property><property name=\"visible\">True</property><property na"
  "me=\"can-focus\">True</property><property name=\"receives-default\">Tru"
  "e</property><property name=\"title\" translatable=\"yes\">Choose tab ac"
  "tivity color</property><property name=\"rgba\">rgb(0,0,0)</property><ch"
  "ild internal-child=\"accessible\"><object class=\"AtkObject\" id=\"tab-"
  "activity-color-atkobject\"><property name=\"AtkObject::accessible-name\""
  " translatable=\"yes\">Color Selector</property><property name=\"AtkObje"
  "ct::accessible-description\" translatable=\"yes\">Open a dialog to spec"
  "ify the color</property></object></child></object><packing><property na"
  "me=\"left-attach\">5</property><property name=\"top-attach\">1</propert"
  "y></packing></child><child><object class=\"GtkCheckButton\" id=\"color-"
  "use-theme\"><property name=\"label\" translatable=\"yes\">_Use system t"
  "heme colors for text and background</property><property name=\"visible\""
  ">True</property><property name=\"can-focus\">True</property><property n"
  "ame=\"receives-default\">False</property><property name=\"halign\">star"
  "t</property><property name=\"use-underline\">True</property><property n"
  "ame=\"draw-indicator\">True</property></object><packing><property name="
  "\"left-attach\">0</property><property name=\"top-attach\">2</property><"
  "property name=\"width\">6</property></packing></child><child><object cl"
  "ass=\"GtkCheckButton\" id=\"color-background-vary\"><property name=\"la"
  "bel\" translatable=\"yes\">_Vary the background color for each tab</pro"
  "perty><property name=\"visible\">True</property><property name=\"can-fo"
  "cus\">True</property><property name=\"receives-default\">False</propert"
  "y><property name=\"tooltip-text\" translatable=\"yes\">The random color"
  " is based on the selected background color, keeping the same brightness"
  ". </property><property name=\"halign\">start</property><property name=\""
  "use-underline\">True</property><property name=\"draw-indicator\">True</"
  "property></object><packing><property name=\"left-attach\">0</property><"
  "property name=\"top-attach\">3</property><property name=\"width\">6</pr"
  "operty></packing></child></object></child><child type=\"label\"><object"
  " class=\"GtkLabel\" id=\"label14\"><property name=\"visible\">True</pro"
  "perty><property name=\"can-focus\">False</property><property name=\"lab"
  "el\" translatable=\"yes\">General</property><property name=\"use-markup"
  "\">True</property><attributes><attribute name=\"weight\" value=\"bold\""
  "/></attributes></object></child></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">0</property></packing></child><child><object class=\"G"
  "tkFrame\" id=\"frame8\"><property name=\"visible\">True</property><prop"
  "erty name=\"can-focus\">False</property><property name=\"label-xalign\""
  ">0</property><property name=\"shadow-type\">none</property><child><obje"
  "ct class=\"GtkGrid\" id=\"grid6\"><property name=\"visible\">True</prop"
  "erty><property name=\"can-focus\">False</property><property name=\"hali"
  "gn\">start</property><property name=\"margin-left\">18</property><prope"
  "rty name=\"margin-right\">12</property><property name=\"margin-top\">6<"
  "/property><property name=\"margin-bottom\">6</property><property name=\""
  "row-spacing\">6</property><property name=\"column-spacing\">12</propert"
  "y><child><object class=\"GtkCheckButton\" id=\"color-bold-custom\"><pro"
  "perty name=\"label\" translatable=\"yes\">B_old text color:</property><"
  "property name=\"visible\">True</property><property name=\"can-focus\">T"
  "rue</property><property name=\"receives-default\">False</property><prop"
  "erty name=\"tooltip-text\" translatable=\"yes\">Enable this option to s"
  "et a custom bold color. If disabled the text color will be used.</prope"
  "rty><property name=\"halign\">start</property><property name=\"use-unde"
  "rline\">True</property><property name=\"draw-indicator\">True</property"
  "></object><packing><property name=\"left-attach\">0</property><property"
  " name=\"top-attach\">2</property></packing></child><child><object class"
  "=\"GtkColorButton\" id=\"color-bold\"><property name=\"use-action-appea"
  "rance\">False</property><property name=\"visible\">True</property><prop"
  "erty name=\"can-focus\">True</property><property name=\"receives-defaul"
  "t\">True</property><property name=\"title\" translatable=\"yes\">Choose"
  " bold font color</property><property name=\"rgba\">rgb(0,0,0)</property"
  "></object><packing><property name=\"left-attach\">1</property><property"
  " name=\"top-attach\">2</property></packing></child><child><object class"
  "=\"GtkCheckButton\" id=\"color-selection-custom\"><property name=\"labe"
  "l\" translatable=\"yes\">Text _selection color:</property><property nam"
  "e=\"visible\">True</property><property name=\"can-focus\">True</propert"
  "y><property name=\"receives-default\">False</property><property name=\""
  "tooltip-text\" translatable=\"yes\">Enable this option to set custom te"
  "xt and background colors for the selection. If disabled the background "
  "and text colors will be reversed.</property><property name=\"halign\">s"
  "tart</property><property name=\"use-underline\">True</property><propert"
  "y name=\"draw-indicator\">True</property></object><packing><property na"
  "me=\"left-attach\">0</property><property name=\"top-attach\">1</propert"
  "y></packing></child><child><object class=\"GtkColorButton\" id=\"color-"
  "selection\"><property name=\"use-action-appearance\">False</property><p"
  "roperty name=\"visible\">True</property><property name=\"can-focus\">Tr"
  "ue</property><property name=\"receives-default\">True</property><proper"
  "ty name=\"title\" translatable=\"yes\">Choose text selection foreground"
  " color</property><property name=\"rgba\">rgb(0,0,0)</property><child in"
  "ternal-child=\"accessible\"><object class=\"AtkObject\" id=\"color-sele"
  "ction-atkobject\"><property name=\"AtkObject::accessible-name\" transla"
  "table=\"yes\">Color Selector</property><property name=\"AtkObject::acce"
  "ssible-description\" translatable=\"yes\">Open a dialog to specify the "
  "color</property></object></child></object><packing><property name=\"lef"
  "t-attach\">1</property><property name=\"top-attach\">1</property></pack"
  "ing></child><child><object class=\"GtkColorButton\" id=\"color-selectio"
  "n-background\"><property name=\"use-action-appearance\">False</property"
  "><property name=\"visible\">True</property><property name=\"can-focus\""
  ">True</property><property name=\"receives-default\">True</property><pro"
  "perty name=\"title\" translatable=\"yes\">Choose text selection backgro"
  "und color</property><property name=\"rgba\">rgb(0,0,0)</property><child"
  " internal-child=\"accessible\"><object class=\"AtkObject\" id=\"color-s"
  "election-background-atkobject\"><property name=\"AtkObject::accessible-"
  "name\" translatable=\"yes\">Color Selector</property><property name=\"A"
  "tkObject::accessible-description\" translatable=\"yes\">Open a dialog t"
  "o specify the color</property></object></child></object><packing><prope"
  "rty name=\"left-attach\">2</property><property name=\"top-attach\">1</p"
  "roperty></packing></child><child><object class=\"GtkCheckButton\" id=\""
  "color-cursor-custom\"><property name=\"label\" translatable=\"yes\">Cu_"
  "rsor color:</property><property name=\"visible\">True</property><proper"
  "ty name=\"can-focus\">True</property><property name=\"receives-default\""
  ">False</property><property name=\"tooltip-text\" translatable=\"yes\">E"
  "nable this option to set custom text and background colors for the curs"
  "or. If disabled the background and text colors will be reversed.</prope"
  "rty><property name=\"halign\">start</property><property name=\"use-unde"
  "rline\">True</property><property name=\"draw-indicator\">True</property"
  "></object><packing><property name=\"left-attach\">0</property><property"
  " name=\"top-attach\">0</property></packing></child><child><object class"
  "=\"GtkColorButton\" id=\"color-cursor\"><property name=\"use-action-app"
  "earance\">False</property><property name=\"visible\">True</property><pr"
  "operty name=\"can-focus\">True</property><property name=\"receives-defa"
  "ult\">True</property><property name=\"title\" translatable=\"yes\">Choo"
  "se cursor background color</property><property name=\"rgba\">rgb(0,0,0)"
  "</property><child internal-child=\"accessible\"><object class=\"AtkObje"
  "ct\" id=\"color-cursor-atkobject\"><property name=\"AtkObject::accessib"
  "le-name\" translatable=\"yes\">Color Selector</property><property name="
  "\"AtkObject::accessible-description\" translatable=\"yes\">Open a dialo"
  "g to specify the color</property></object></child></object><packing><pr"
  "operty name=\"left-attach\">2</property><property name=\"top-attach\">0"
  "</property></packing></child><child><object class=\"GtkColorButton\" id"
  "=\"color-cursor-foreground\"><property name=\"use-action-appearance\">F"
  "alse</property><property name=\"visible\">True</property><property name"
  "=\"can-focus\">True</property><property name=\"receives-default\">True<"
  "/property><property name=\"title\" translatable=\"yes\">Choose cursor f"
  "oreground color</property><property name=\"rgba\">rgb(0,0,0)</property>"
  "<child internal-child=\"accessible\"><object class=\"AtkObject\" id=\"c"
  "olor-cursor-foreground-atkobject\"><property name=\"AtkObject::accessib"
  "le-name\" translatable=\"yes\">Color Selector</property><property name="
  "\"AtkObject::accessible-description\" translatable=\"yes\">Open a dialo"
  "g to specify the color</property></object></child></object><packing><pr"
  "operty name=\"left-attach\">1</property><property name=\"top-attach\">0"
  "</property></packing></child><child><placeholder/></child></object></ch"
  "ild><child type=\"label\"><object class=\"GtkLabel\" id=\"label18\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Fal"
  "se</property><property name=\"label\" translatable=\"yes\">Custom Color"
  "s</property><property name=\"use-markup\">True</property><attributes><a"
  "ttribute name=\"weight\" value=\"bold\"/></attributes></object></child>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">1</property></p"
  "acking></child><child><object class=\"GtkFrame\" id=\"frame9\"><propert"
  "y name=\"visible\">True</property><property name=\"can-focus\">False</p"
  "roperty><property name=\"label-xalign\">0</property><property name=\"sh"
  "adow-type\">none</property><child><object class=\"GtkGrid\" id=\"grid4\""
  "><property name=\"visible\">True</property><property name=\"can-focus\""
  ">False</property><property name=\"margin-left\">18</property><property "
  "name=\"margin-right\">6</property><property name=\"margin-top\">6</prop"
  "erty><property name=\"margin-bottom\">6</property><property name=\"row-"
  "spacing\">6</property><property name=\"column-spacing\">6</property><ch"
  "ild><object class=\"GtkColorButton\" id=\"color-palette1\"><property na"
  "me=\"use-action-appearance\">False</property><property name=\"visible\""
  ">True</property><property name=\"can-focus\">True</property><property n"
  "ame=\"receives-default\">True</property><property name=\"tooltip-text\""
  " translatable=\"yes\">Black</property><property name=\"rgba\">rgb(0,0,0"
  ")</property><child internal-child=\"accessible\"><object class=\"AtkObj"
  "ect\" id=\"color-palette1-atkobject\"><property name=\"AtkObject::acces"
  "sible-name\" translatable=\"yes\">Color Selector</property><property na"
  "me=\"AtkObject::accessible-description\" translatable=\"yes\">Open a di"
  "alog to specify the color</property></object></child></object><packing>"
  "<property name=\"left-attach\">0</property><property name=\"top-attach\""
  ">0</property></packing></child><child><object class=\"GtkColorButton\" "
  "id=\"color-palette9\"><property name=\"use-action-appearance\">False</p"
  "roperty><property name=\"visible\">True</property><property name=\"can-"
  "focus\">True</property><property name=\"receives-default\">True</proper"
  "ty><property name=\"tooltip-text\" translatable=\"yes\">Dark Gray</prop"
  "erty><property name=\"rgba\">rgb(0,0,0)</property><child internal-child"
  "=\"accessible\"><object class=\"AtkObject\" id=\"color-palette9-atkobje"
  "ct\"><property name=\"AtkObject::accessible-name\" translatable=\"yes\""
  ">Color Selector</property><property name=\"AtkObject::accessible-descri"
  "ption\" translatable=\"yes\">Open a dialog to specify the color</proper"
  "ty></object></child></object><packing><property name=\"left-attach\">0<"
  "/property><property name=\"top-attach\">1</property></packing></child><"
  "child><object class=\"GtkColorButton\" id=\"color-palette2\"><property "
  "name=\"use-action-appearance\">False</property><property name=\"visible"
  "\">True</property><property name=\"can-focus\">True</property><property"
  " name=\"receives-default\">True</property><property name=\"tooltip-text"
  "\" translatable=\"yes\">Red</property><property name=\"rgba\">rgb(0,0,0"
  ")</property><child internal-child=\"accessible\"><object class=\"AtkObj"
  "ect\" id=\"color-palette2-atkobject\"><property name=\"AtkObject::acces"
  "sible-name\" translatable=\"yes\">Color Selector</property><property na"
  "me=\"AtkObject::accessible-description\" translatable=\"yes\">Open a di"
  "alog to specify the color</property></object></child></object><packing>"
  "<property name=\"left-attach\">1</property><property name=\"top-attach\""
  ">0</property></packing></child><child><object class=\"GtkColorButton\" "
  "id=\"color-palette10\"><property name=\"use-action-appearance\">False</"
  "property><property name=\"visible\">True</property><property name=\"can"
  "-focus\">True</property><property name=\"receives-default\">True</prope"
  "rty><property name=\"tooltip-text\" translatable=\"yes\">Light Red</pro"
  "perty><property name=\"rgba\">rgb(0,0,0)</property><child internal-chil"
  "d=\"accessible\"><object class=\"AtkObject\" id=\"color-palette10-atkob"
  "ject\"><property name=\"AtkObject::accessible-name\" translatable=\"yes"
  "\">Color Selector</property><property name=\"AtkObject::accessible-desc"
  "ription\" translatable=\"yes\">Open a dialog to specify the color</prop"
  "erty></object></child></object><packing><property name=\"left-attach\">"
  "1</property><property name=\"top-attach\">1</property></packing></child"
  "><child><object class=\"GtkColorButton\" id=\"color-palette3\"><propert"
  "y name=\"use-action-appearance\">False</property><property name=\"visib"
  "le\">True</property><property name=\"can-focus\">True</property><proper"
  "ty name=\"receives-default\">True</property><property name=\"tooltip-te"
  "xt\" translatable=\"yes\">Green</property><property name=\"rgba\">rgb(0"
  ",0,0)</property><child internal-child=\"accessible\"><object class=\"At"
  "kObject\" id=\"color-palette3-atkobject\"><property name=\"AtkObject::a"
  "ccessible-name\" translatable=\"yes\">Color Selector</property><propert"
  "y name=\"AtkObject::accessible-description\" translatable=\"yes\">Open "
  "a dialog to specify the color</property></object></child></object><pack"
  "ing><property name=\"left-attach\">2</property><property name=\"top-att"
  "ach\">0</property></packing></child><child><object class=\"GtkColorButt"
  "on\" id=\"color-palette11\"><property name=\"use-action-appearance\">Fa"
  "lse</property><property name=\"visible\">True</property><property name="
  "\"can-focus\">True</property><property name=\"receives-default\">True</"
  "property><property name=\"tooltip-text\" translatable=\"yes\">Light Gre"
  "en</property><property name=\"rgba\">rgb(0,0,0)</property><child intern"
  "al-child=\"accessible\"><object class=\"AtkObject\" id=\"color-palette1"
  "1-atkobject\"><property name=\"AtkObject::accessible-name\" translatabl"
  "e=\"yes\">Color Selector</property><property name=\"AtkObject::accessib"
  "le-description\" translatable=\"yes\">Open a dialog to specify the colo"
  "r</property></object></child></object><packing><property name=\"left-at"
  "tach\">2</property><property name=\"top-attach\">1</property></packing>"
  "</child><child><object class=\"GtkColorButton\" id=\"color-palette4\"><"
  "property name=\"use-action-appearance\">False</property><property name="
  "\"visible\">True</property><property name=\"can-focus\">True</property>"
  "<property name=\"receives-default\">True</property><property name=\"too"
  "ltip-text\" translatable=\"yes\">Brown / Yellow</property><property nam"
  "e=\"rgba\">rgb(0,0,0)</property><child internal-child=\"accessible\"><o"
  "bject class=\"AtkObject\" id=\"color-palette4-atkobject\"><property nam"
  "e=\"AtkObject::accessible-name\" translatable=\"yes\">Color Selector</p"
  "roperty><property name=\"AtkObject::accessible-description\" translatab"
  "le=\"yes\">Open a dialog to specify the color</property></object></chil"
  "d></object><packing><property name=\"left-attach\">3</property><propert"
  "y name=\"top-attach\">0</property></packing></child><child><object clas"
  "s=\"GtkColorButton\" id=\"color-palette12\"><property name=\"use-action"
  "-appearance\">False</property><property name=\"visible\">True</property"
  "><property name=\"can-focus\">True</property><property name=\"receives-"
  "default\">True</property><property name=\"tooltip-text\" translatable=\""
  "yes\">Yellow</property><property name=\"rgba\">rgb(0,0,0)</property><ch"
  "ild internal-child=\"accessible\"><object class=\"AtkObject\" id=\"colo"
  "r-palette12-atkobject\"><property name=\"AtkObject::accessible-name\" t"
  "ranslatable=\"yes\">Color Selector</property><property name=\"AtkObject"
  "::accessible-description\" translatable=\"yes\">Open a dialog to specif"
  "y the color</property></object></child></object><packing><property name"
  "=\"left-attach\">3</property><property name=\"top-attach\">1</property>"
  "</packing></child><child><object class=\"GtkColorButton\" id=\"color-pa"
  "lette5\"><property name=\"use-action-appearance\">False</property><prop"
  "erty name=\"visible\">True</property><property name=\"can-focus\">True<"
  "/property><property name=\"receives-default\">True</property><property "
  "name=\"tooltip-text\" translatable=\"yes\">Blue</property><property nam"
  "e=\"rgba\">rgb(0,0,0)</property><child internal-child=\"accessible\"><o"
  "bject class=\"AtkObject\" id=\"color-palette5-atkobject\"><property nam"
  "e=\"AtkObject::accessible-name\" translatable=\"yes\">Color Selector</p"
  "roperty><property name=\"AtkObject::accessible-description\" translatab"
  "le=\"yes\">Open a dialog to specify the color</property></object></chil"
  "d></object><packing><property name=\"left-attach\">4</property><propert"
  "y name=\"top-attach\">0</property></packing></child><child><object clas"
  "s=\"GtkColorButton\" id=\"color-palette13\"><property name=\"use-action"
  "-appearance\">False</property><property name=\"visible\">True</property"
  "><property name=\"can-focus\">True</property><property name=\"receives-"
  "default\">True</property><property name=\"tooltip-text\" translatable=\""
  "yes\">Light Blue</property><property name=\"rgba\">rgb(0,0,0)</property"
  "><child internal-child=\"accessible\"><object class=\"AtkObject\" id=\""
  "color-palette13-atkobject\"><property name=\"AtkObject::accessible-name"
  "\" translatable=\"yes\">Color Selector</property><property name=\"AtkOb"
  "ject::accessible-description\" translatable=\"yes\">Open a dialog to sp"
  "ecify the color</property></object></child></object><packing><property "
  "name=\"left-attach\">4</property><property name=\"top-attach\">1</prope"
  "rty></packing></child><child><object class=\"GtkColorButton\" id=\"colo"
  "r-palette6\"><property name=\"use-action-appearance\">False</property><"
  "property name=\"visible\">True</property><property name=\"can-focus\">T"
  "rue</property><property name=\"receives-default\">True</property><prope"
  "rty name=\"tooltip-text\" translatable=\"yes\">Magenta</property><prope"
  "rty name=\"rgba\">rgb(0,0,0)</property><child internal-child=\"accessib"
  "le\"><object class=\"AtkObject\" id=\"color-palette6-atkobject\"><prope"
  "rty name=\"AtkObject::accessible-name\" translatable=\"yes\">Color Sele"
  "ctor</property><property name=\"AtkObject::accessible-description\" tra"
  "nslatable=\"yes\">Open a dialog to specify the color</property></object"
  "></child></object><packing><property name=\"left-attach\">5</property><"
  "property name=\"top-attach\">0</property></packing></child><child><obje"
  "ct class=\"GtkColorButton\" id=\"color-palette14\"><property name=\"use"
  "-action-appearance\">False</property><property name=\"visible\">True</p"
  "roperty><property name=\"can-focus\">True</property><property name=\"re"
  "ceives-default\">True</property><property name=\"tooltip-text\" transla"
  "table=\"yes\">Light Magenta</property><property name=\"rgba\">rgb(0,0,0"
  ")</property><child internal-child=\"accessible\"><object class=\"AtkObj"
  "ect\" id=\"color-palette14-atkobject\"><property name=\"AtkObject::acce"
  "ssible-name\" translatable=\"yes\">Color Selector</property><property n"
  "ame=\"AtkObject::accessible-description\" translatable=\"yes\">Open a d"
  "ialog to specify the color</property></object></child></object><packing"
  "><property name=\"left-attach\">5</property><property name=\"top-attach"
  "\">1</property></packing></child><child><object class=\"GtkColorButton\""
  " id=\"color-palette7\"><property name=\"use-action-appearance\">False</"
  "property><property name=\"visible\">True</property><property name=\"can"
  "-focus\">True</property><property name=\"receives-default\">True</prope"
  "rty><property name=\"tooltip-text\" translatable=\"yes\">Cyan</property"
  "><property name=\"rgba\">rgb(0,0,0)</property><child internal-child=\"a"
  "ccessible\"><object class=\"AtkObject\" id=\"color-palette7-atkobject\""
  "><property name=\"AtkObject::accessible-name\" translatable=\"yes\">Col"
  "or Selector</property><property name=\"AtkObject::accessible-descriptio"
  "n\" translatable=\"yes\">Open a dialog to specify the color</property><"
  "/object></child></object><packing><property name=\"left-attach\">6</pro"
  "perty><property name=\"top-attach\">0</property></packing></child><chil"
  "d><object class=\"GtkColorButton\" id=\"color-palette15\"><property nam"
  "e=\"use-action-appearance\">False</property><property name=\"visible\">"
  "True</property><property name=\"can-focus\">True</property><property na"
  "me=\"receives-default\">True</property><property name=\"tooltip-text\" "
  "translatable=\"yes\">Light Cyan</property><property name=\"rgba\">rgb(0"
  ",0,0)</property><child internal-child=\"accessible\"><object class=\"At"
  "kObject\" id=\"color-palette15-atkobject\"><property name=\"AtkObject::"
  "accessible-name\" translatable=\"yes\">Color Selector</property><proper"
  "ty name=\"AtkObject::accessible-description\" translatable=\"yes\">Open"
  " a dialog to specify the color</property></object></child></object><pac"
  "king><property name=\"left-attach\">6</property><property name=\"top-at"
  "tach\">1</property></packing></child><child><object class=\"GtkColorBut"
  "ton\" id=\"color-palette8\"><property name=\"use-action-appearance\">Fa"
  "lse</property><property name=\"visible\">True</property><property name="
  "\"can-focus\">True</property><property name=\"receives-default\">True</"
  "property><property name=\"tooltip-text\" translatable=\"yes\">Light Gra"
  "y</property><property name=\"rgba\">rgb(0,0,0)</property><child interna"
  "l-child=\"accessible\"><object class=\"AtkObject\" id=\"color-palette8-"
  "atkobject\"><property name=\"AtkObject::accessible-name\" translatable="
  "\"yes\">Color Selector</property><property name=\"AtkObject::accessible"
  "-description\" translatable=\"yes\">Open a dialog to specify the color<"
  "/property></object></child></object><packing><property name=\"left-atta"
  "ch\">7</property><property name=\"top-attach\">0</property></packing></"
  "child><child><object class=\"GtkColorButton\" id=\"color-palette16\"><p"
  "roperty name=\"use-action-appearance\">False</property><property name=\""
  "visible\">True</property><property name=\"can-focus\">True</property><p"
  "roperty name=\"receives-default\">True</property><property name=\"toolt"
  "ip-text\" translatable=\"yes\">White</property><property name=\"rgba\">"
  "rgb(0,0,0)</property><child internal-child=\"accessible\"><object class"
  "=\"AtkObject\" id=\"color-palette16-atkobject\"><property name=\"AtkObj"
  "ect::accessible-name\" translatable=\"yes\">Color Selector</property><p"
  "roperty name=\"AtkObject::accessible-description\" translatable=\"yes\""
  ">Open a dialog to specify the color</property></object></child></object"
  "><packing><property name=\"left-attach\">7</property><property name=\"t"
  "op-attach\">1</property></packing></child><child><object class=\"GtkChe"
  "ckButton\" id=\"color-bold-is-bright\"><property name=\"label\" transla"
  "table=\"yes\">Show bold text in b_right colors</property><property name"
  "=\"visible\">True</property><property name=\"can-focus\">True</property"
  "><property name=\"receives-default\">False</property><property name=\"t"
  "ooltip-text\" translatable=\"yes\">Enable this option to allow escape s"
  "equences such as \'\\e[1;35m\' to switch text to bright colors in addit"
  "ion to bold. If disabled, text color will remain intact.</property><pro"
  "perty name=\"halign\">start</property><property name=\"use-underline\">"
  "True</property><property name=\"draw-indicator\">True</property></objec"
  "t><packing><property name=\"left-attach\">0</property><property name=\""
  "top-attach\">2</property><property name=\"width\">8</property></packing"
  "></child></object></child><child type=\"label\"><object class=\"GtkLabe"
  "l\" id=\"label19\"><property name=\"visible\">True</property><property "
  "name=\"can-focus\">False</property><property name=\"label\" translatabl"
  "e=\"yes\">Palette</property><property name=\"use-markup\">True</propert"
  "y><attributes><attribute name=\"weight\" value=\"bold\"/></attributes><"
  "/object></child></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">True</property><property name=\"position\""
  ">2</property></packing></child><child><object class=\"GtkFrame\" id=\"c"
  "olor-presets-frame\"><property name=\"visible\">True</property><propert"
  "y name=\"can-focus\">False</property><property name=\"label-xalign\">0<"
  "/property><property name=\"shadow-type\">none</property><child><object "
  "class=\"GtkAlignment\" id=\"alignment21\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can-focus\">False</property><property nam"
  "e=\"xalign\">0</property><property name=\"xscale\">0</property><propert"
  "y name=\"top-padding\">6</property><property name=\"left-padding\">18</"
  "property><child><object class=\"GtkComboBox\" id=\"color-presets\"><pro"
  "perty name=\"visible\">True</property><property name=\"can-focus\">Fals"
  "e</property><child><object class=\"GtkCellRendererText\" id=\"cellrende"
  "rertext8\"/><attributes><attribute name=\"text\">0</attribute></attribu"
  "tes></child></object></child></object></child><child type=\"label\"><ob"
  "ject class=\"GtkLabel\" id=\"label17\"><property name=\"visible\">True<"
  "/property><property name=\"can-focus\">False</property><property name=\""
  "label\" translatable=\"yes\">Presets</property><property name=\"use-mar"
  "kup\">True</property><attributes><attribute name=\"weight\" value=\"bol"
  "d\"/></attributes></object></child></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">3</property></packing></child></object><packing><pr"
  "operty name=\"position\">3</property></packing></child><child type=\"ta"
  "b\"><object class=\"GtkLabel\" id=\"label3\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">_Colors</property><property name=\""
  "use-underline\">True</property></object><packing><property name=\"posit"
  "ion\">3</property><property name=\"tab-fill\">False</property></packing"
  "></child><child><object class=\"GtkBox\" id=\"vbox11\"><property name=\""
  "visible\">True</property><property name=\"can-focus\">False</property><"
  "property name=\"border-width\">6</property><property name=\"orientation"
  "\">vertical</property><property name=\"spacing\">6</property><child><ob"
  "ject class=\"GtkFrame\" id=\"frame12\"><property name=\"visible\">True<"
  "/property><property name=\"can-focus\">False</property><property name=\""
  "label-xalign\">0</property><property name=\"shadow-type\">none</propert"
  "y><child><object class=\"GtkBox\" id=\"box1\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">False</property><property "
  "name=\"orientation\">vertical</property><child><object class=\"GtkInfoB"
  "ar\" id=\"infobar1\"><property name=\"visible\">True</property><propert"
  "y name=\"app-paintable\">True</property><property name=\"can-focus\">Fa"
  "lse</property><child internal-child=\"action_area\"><object class=\"Gtk"
  "ButtonBox\" id=\"infobar-action_area1\"><property name=\"can-focus\">Fa"
  "lse</property><property name=\"spacing\">6</property><property name=\"l"
  "ayout-style\">end</property><child><placeholder/></child><child><placeh"
  "older/></child><child><placeholder/></child></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">False</propert"
  "y><property name=\"position\">0</property></packing></child><child inte"
  "rnal-child=\"content_area\"><object class=\"GtkBox\" id=\"infobar-conte"
  "nt_area1\"><property name=\"can-focus\">False</property><property name="
  "\"spacing\">16</property><child><placeholder/></child><child><object cl"
  "ass=\"GtkLabel\" id=\"label34\"><property name=\"visible\">True</proper"
  "ty><property name=\"can-focus\">False</property><property name=\"label\""
  " translatable=\"yes\">These options may cause some applications to beha"
  "ve\nincorrectly. They are only here to allow you to work around\ncertai"
  "n applications and operating systems that expect\ndifferent terminal be"
  "havior.</property><property name=\"wrap\">True</property><property name"
  "=\"max-width-chars\">80</property></object><packing><property name=\"ex"
  "pand\">False</property><property name=\"fill\">True</property><property"
  " name=\"position\">1</property></packing></child><child><placeholder/><"
  "/child></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">False</property><property name=\"position\">0</prop"
  "erty></packing></child></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">0</property></packing></child><child><object class=\"GtkGrid\" "
  "id=\"grid2\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">False</property><property name=\"margin-left\">24</property"
  "><property name=\"margin-right\">12</property><property name=\"margin-t"
  "op\">6</property><property name=\"margin-bottom\">6</property><property"
  " name=\"row-spacing\">6</property><property name=\"column-spacing\">12<"
  "/property><property name=\"column-homogeneous\">True</property><child><"
  "object class=\"GtkLabel\" id=\"label31\"><property name=\"visible\">Tru"
  "e</property><property name=\"can-focus\">False</property><property name"
  "=\"halign\">start</property><property name=\"label\" translatable=\"yes"
  "\">_Backspace key generates:</property><property name=\"use-underline\""
  ">True</property></object><packing><property name=\"left-attach\">0</pro"
  "perty><property name=\"top-attach\">0</property></packing></child><chil"
  "d><object class=\"GtkComboBox\" id=\"binding-backspace\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">False</propert"
  "y><property name=\"model\">liststore4</property><child><object class=\""
  "GtkCellRendererText\" id=\"cellrenderertext4\"/><attributes><attribute "
  "name=\"text\">0</attribute></attributes></child></object><packing><prop"
  "erty name=\"left-attach\">1</property><property name=\"top-attach\">0</"
  "property></packing></child><child><object class=\"GtkLabel\" id=\"label"
  "32\"><property name=\"visible\">True</property><property name=\"can-foc"
  "us\">False</property><property name=\"halign\">start</property><propert"
  "y name=\"label\" translatable=\"yes\">_Delete key generates:</property>"
  "<property name=\"use-underline\">True</property></object><packing><prop"
  "erty name=\"left-attach\">0</property><property name=\"top-attach\">1</"
  "property></packing></child><child><object class=\"GtkComboBox\" id=\"bi"
  "nding-delete\"><property name=\"visible\">True</property><property name"
  "=\"can-focus\">False</property><property name=\"model\">liststore5</pro"
  "perty><child><object class=\"GtkCellRendererText\" id=\"cellrenderertex"
  "t5\"/><attributes><attribute name=\"text\">0</attribute></attributes></"
  "child></object><packing><property name=\"left-attach\">1</property><pro"
  "perty name=\"top-attach\">1</property></packing></child><child><object "
  "class=\"GtkButton\" id=\"reset-compatibility\"><property name=\"label\""
  " translatable=\"yes\">_Reset compatibility options to defaults</propert"
  "y><property name=\"visible\">True</property><property name=\"can-focus\""
  ">True</property><property name=\"receives-default\">True</property><pro"
  "perty name=\"use-underline\">True</property></object><packing><property"
  " name=\"left-attach\">0</property><property name=\"top-attach\">3</prop"
  "erty><property name=\"width\">2</property></packing></child><child><obj"
  "ect class=\"GtkLabel\" id=\"label33\"><property name=\"visible\">True</"
  "property><property name=\"can-focus\">False</property><property name=\""
  "halign\">start</property><property name=\"label\" translatable=\"yes\">"
  "_Ambiguous-width characters:</property><property name=\"use-underline\""
  ">True</property></object><packing><property name=\"left-attach\">0</pro"
  "perty><property name=\"top-attach\">2</property></packing></child><chil"
  "d><object class=\"GtkComboBox\" id=\"binding-ambiguous-width\"><propert"
  "y name=\"visible\">True</property><property name=\"can-focus\">False</p"
  "roperty><property name=\"model\">liststore8</property><child><object cl"
  "ass=\"GtkCellRendererText\" id=\"cellrenderertext10\"/><attributes><att"
  "ribute name=\"text\">0</attribute></attributes></child></object><packin"
  "g><property name=\"left-attach\">1</property><property name=\"top-attac"
  "h\">2</property></packing></child><child><placeholder/></child><child><"
  "placeholder/></child><child><placeholder/></child><child><placeholder/>"
  "</child></object><packing><property name=\"expand\">False</property><pr"
  "operty name=\"fill\">True</property><property name=\"position\">1</prop"
  "erty></packing></child></object></child><child type=\"label\"><object c"
  "lass=\"GtkLabel\" id=\"label25\"><property name=\"visible\">True</prope"
  "rty><property name=\"can-focus\">False</property><property name=\"label"
  "\" translatable=\"yes\">Compatibility</property><property name=\"use-ma"
  "rkup\">True</property><attributes><attribute name=\"weight\" value=\"bo"
  "ld\"/></attributes></object></child></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">0</property></packing></child></object><packing><p"
  "roperty name=\"position\">4</property></packing></child><child type=\"t"
  "ab\"><object class=\"GtkLabel\" id=\"label21\"><property name=\"visible"
  "\">True</property><property name=\"can-focus\">False</property><propert"
  "y name=\"label\" translatable=\"yes\">Co_mpatibility</property><propert"
  "y name=\"use-underline\">True</property></object><packing><property nam"
  "e=\"position\">4</property><property name=\"tab-fill\">False</property>"
  "</packing></child><child><object class=\"GtkBox\" id=\"vbox13\"><proper"
  "ty name=\"visible\">True</property><property name=\"can-focus\">False</"
  "property><property name=\"border-width\">6</property><property name=\"o"
  "rientation\">vertical</property><property name=\"spacing\">6</property>"
  "<child><object class=\"GtkFrame\" id=\"frame13\"><property name=\"visib"
  "le\">True</property><property name=\"can-focus\">False</property><prope"
  "rty name=\"label-xalign\">0</property><property name=\"shadow-type\">no"
  "ne</property><child><object class=\"GtkAlignment\" id=\"alignment16\"><"
  "property name=\"visible\">True</property><property name=\"can-focus\">F"
  "alse</property><property name=\"left-padding\">12</property><child><obj"
  "ect class=\"GtkBox\" id=\"hbox8\"><property name=\"visible\">True</prop"
  "erty><property name=\"can-focus\">False</property><property name=\"bord"
  "er-width\">6</property><property name=\"spacing\">6</property><child><o"
  "bject class=\"GtkLabel\" id=\"label30\"><property name=\"visible\">True"
  "</property><property name=\"can-focus\">False</property><property name="
  "\"halign\">start</property><property name=\"label\" translatable=\"yes\""
  ">Consider the following\ncharacters part of a _word\nwhen double clicki"
  "ng:</property><property name=\"use-underline\">True</property><property"
  " name=\"mnemonic-widget\">word-chars</property></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">True</prope"
  "rty><property name=\"position\">0</property></packing></child><child><o"
  "bject class=\"GtkEntry\" id=\"word-chars\"><property name=\"visible\">T"
  "rue</property><property name=\"can-focus\">True</property><property nam"
  "e=\"valign\">center</property><property name=\"invisible-char\">\342\200"
  "\242</property><property name=\"primary-icon-activatable\">False</prope"
  "rty><property name=\"secondary-icon-activatable\">False</property></obj"
  "ect><packing><property name=\"expand\">True</property><property name=\""
  "fill\">True</property><property name=\"position\">1</property></packing"
  "></child><child><object class=\"GtkButton\" id=\"reset-word-chars\"><pr"
  "operty name=\"label\" translatable=\"yes\">Rese_t</property><property n"
  "ame=\"visible\">True</property><property name=\"can-focus\">True</prope"
  "rty><property name=\"receives-default\">True</property><property name=\""
  "tooltip-text\" translatable=\"yes\">Reset double click options to defau"
  "lts</property><property name=\"valign\">center</property><property name"
  "=\"use-underline\">True</property></object><packing><property name=\"ex"
  "pand\">False</property><property name=\"fill\">True</property><property"
  " name=\"position\">2</property></packing></child></object></child></obj"
  "ect></child><child type=\"label\"><object class=\"GtkLabel\" id=\"label"
  "26\"><property name=\"visible\">True</property><property name=\"can-foc"
  "us\">False</property><property name=\"label\" translatable=\"yes\">Doub"
  "le Click</property><property name=\"use-markup\">True</property><attrib"
  "utes><attribute name=\"weight\" value=\"bold\"/></attributes></object><"
  "/child></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">True</property><property name=\"position\">0</prope"
  "rty></packing></child><child><object class=\"GtkFrame\" id=\"frame15\">"
  "<property name=\"visible\">True</property><property name=\"can-focus\">"
  "False</property><property name=\"label-xalign\">0</property><property n"
  "ame=\"shadow-type\">none</property><child><object class=\"GtkAlignment\""
  " id=\"alignment9\"><property name=\"visible\">True</property><property "
  "name=\"can-focus\">False</property><property name=\"left-padding\">12</"
  "property><child><object class=\"GtkBox\" id=\"hbox5\"><property name=\""
  "visible\">True</property><property name=\"can-focus\">False</property><"
  "property name=\"border-width\">6</property><property name=\"spacing\">1"
  "2</property><child><object class=\"GtkLabel\" id=\"encoding-label\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Fal"
  "se</property><property name=\"label\" translatable=\"yes\">Default char"
  "acter e_ncoding:</property><property name=\"use-underline\">True</prope"
  "rty><property name=\"mnemonic-widget\">encoding-combo</property></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">True</property><property name=\"position\">0</property></packing>"
  "</child><child><object class=\"GtkComboBox\" id=\"encoding-combo\"><pro"
  "perty name=\"visible\">True</property><property name=\"can-focus\">Fals"
  "e</property><child><object class=\"GtkCellRendererText\" id=\"cellrende"
  "rertext7\"/><attributes><attribute name=\"text\">0</attribute></attribu"
  "tes></child></object><packing><property name=\"expand\">True</property>"
  "<property name=\"fill\">True</property><property name=\"position\">1</p"
  "roperty></packing></child></object></child></object></child><child type"
  "=\"label\"><object class=\"GtkLabel\" id=\"label16\"><property name=\"v"
  "isible\">True</property><property name=\"can-focus\">False</property><p"
  "roperty name=\"label\" translatable=\"yes\">Encoding</property><attribu"
  "tes><attribute name=\"weight\" value=\"bold\"/></attributes></object></"
  "child></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">1</proper"
  "ty></packing></child><child><object class=\"GtkFrame\" id=\"frame11\"><"
  "property name=\"visible\">True</property><property name=\"can-focus\">F"
  "alse</property><property name=\"label-xalign\">0</property><property na"
  "me=\"shadow-type\">none</property><child><object class=\"GtkAlignment\""
  " id=\"alignment14\"><property name=\"visible\">True</property><property"
  " name=\"can-focus\">False</property><property name=\"left-padding\">12<"
  "/property><child><object class=\"GtkBox\" id=\"vbox12\"><property name="
  "\"visible\">True</property><property name=\"can-focus\">False</property"
  "><property name=\"border-width\">6</property><property name=\"orientati"
  "on\">vertical</property><property name=\"spacing\">6</property><child><"
  "object class=\"GtkCheckButton\" id=\"shortcuts-no-mnemonics\"><property"
  " name=\"label\" translatable=\"yes\">Disable all me_nu access keys (suc"
  "h as Alt+f)</property><property name=\"visible\">True</property><proper"
  "ty name=\"can-focus\">True</property><property name=\"receives-default\""
  ">False</property><property name=\"halign\">start</property><property na"
  "me=\"use-underline\">True</property><property name=\"draw-indicator\">T"
  "rue</property></object><packing><property name=\"expand\">True</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">0<"
  "/property></packing></child><child><object class=\"GtkCheckButton\" id="
  "\"shortcuts-no-menukey\"><property name=\"label\" translatable=\"yes\">"
  "Disable m_enu shortcut key (F10 by default)</property><property name=\""
  "visible\">True</property><property name=\"can-focus\">True</property><p"
  "roperty name=\"receives-default\">False</property><property name=\"hali"
  "gn\">start</property><property name=\"use-underline\">True</property><p"
  "roperty name=\"draw-indicator\">True</property></object><packing><prope"
  "rty name=\"expand\">True</property><property name=\"fill\">True</proper"
  "ty><property name=\"position\">1</property></packing></child><child><ob"
  "ject class=\"GtkCheckButton\" id=\"shortcuts-no-helpkey\"><property nam"
  "e=\"label\" translatable=\"yes\">Disable _help window shortcut key (F1 "
  "by default)</property><property name=\"visible\">True</property><proper"
  "ty name=\"can-focus\">True</property><property name=\"receives-default\""
  ">False</property><property name=\"halign\">start</property><property na"
  "me=\"use-underline\">True</property><property name=\"draw-indicator\">T"
  "rue</property></object><packing><property name=\"expand\">True</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">2<"
  "/property></packing></child></object></child></object></child><child ty"
  "pe=\"label\"><object class=\"GtkLabel\" id=\"label24\"><property name=\""
  "visible\">True</property><property name=\"can-focus\">False</property><"
  "property name=\"label\" translatable=\"yes\">Shortcuts</property><prope"
  "rty name=\"use-markup\">True</property><attributes><attribute name=\"we"
  "ight\" value=\"bold\"/></attributes></object></child></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">2</property></packing></child><ch"
  "ild><object class=\"GtkFrame\" id=\"frame19\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">False</property><property "
  "name=\"label-xalign\">0</property><property name=\"shadow-type\">none</"
  "property><child><object class=\"GtkAlignment\" id=\"alignment27\"><prop"
  "erty name=\"visible\">True</property><property name=\"can-focus\">False"
  "</property><property name=\"left-padding\">12</property><child><object "
  "class=\"GtkBox\" id=\"vbox19\"><property name=\"visible\">True</propert"
  "y><property name=\"can-focus\">False</property><property name=\"border-"
  "width\">6</property><property name=\"orientation\">vertical</property><"
  "property name=\"spacing\">6</property><child><object class=\"GtkCheckBu"
  "tton\" id=\"misc-tab-close-middle-click\"><property name=\"label\" tran"
  "slatable=\"yes\">Use _middle mouse click to close tabs</property><prope"
  "rty name=\"visible\">True</property><property name=\"can-focus\">True</"
  "property><property name=\"receives-default\">False</property><property "
  "name=\"halign\">start</property><property name=\"use-underline\">True</"
  "property><property name=\"draw-indicator\">True</property></object><pac"
  "king><property name=\"expand\">True</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">0</property></packing></child"
  "><child><object class=\"GtkCheckButton\" id=\"misc-middle-click-opens-u"
  "ri\"><property name=\"label\" translatable=\"yes\">Use middle mouse cli"
  "ck to open _URLs</property><property name=\"visible\">True</property><p"
  "roperty name=\"can-focus\">True</property><property name=\"receives-def"
  "ault\">False</property><property name=\"tooltip-text\" translatable=\"y"
  "es\">If disabled, URLs can be opened by Ctrl + left mouse click.</prope"
  "rty><property name=\"halign\">start</property><property name=\"use-unde"
  "rline\">True</property><property name=\"draw-indicator\">True</property"
  "></object><packing><property name=\"expand\">True</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">1</property></p"
  "acking></child><child><object class=\"GtkCheckButton\" id=\"misc-mouse-"
  "autohide\"><property name=\"label\" translatable=\"yes\">Auto-hi_de mou"
  "se pointer</property><property name=\"visible\">True</property><propert"
  "y name=\"can-focus\">True</property><property name=\"receives-default\""
  ">False</property><property name=\"halign\">start</property><property na"
  "me=\"use-underline\">True</property><property name=\"draw-indicator\">T"
  "rue</property></object><packing><property name=\"expand\">True</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">2<"
  "/property></packing></child><child><object class=\"GtkCheckButton\" id="
  "\"misc-rewrap-on-resize\"><property name=\"label\" translatable=\"yes\""
  ">Re_wrap terminal contents on resize</property><property name=\"visible"
  "\">True</property><property name=\"can-focus\">True</property><property"
  " name=\"receives-default\">False</property><property name=\"halign\">st"
  "art</property><property name=\"use-underline\">True</property><property"
  " name=\"draw-indicator\">True</property></object><packing><property nam"
  "e=\"expand\">True</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">3</property></packing></child><child><object cl"
  "ass=\"GtkCheckButton\" id=\"misc-new-tab-adjacent\"><property name=\"la"
  "bel\" translatable=\"yes\">Open new tab to the _right of the active tab"
  "</property><property name=\"visible\">True</property><property name=\"c"
  "an-focus\">True</property><property name=\"receives-default\">False</pr"
  "operty><property name=\"tooltip-text\" translatable=\"yes\">If disabled"
  ", new tab will be opened in the rightmost position.</property><property"
  " name=\"halign\">start</property><property name=\"use-underline\">True<"
  "/property><property name=\"draw-indicator\">True</property></object><pa"
  "cking><property name=\"expand\">True</property><property name=\"fill\">"
  "True</property><property name=\"position\">4</property></packing></chil"
  "d><child><object class=\"GtkCheckButton\" id=\"misc-bell\"><property na"
  "me=\"label\" translatable=\"yes\">_Audible bell</property><property nam"
  "e=\"visible\">True</property><property name=\"can-focus\">True</propert"
  "y><property name=\"receives-default\">False</property><property name=\""
  "tooltip-text\" translatable=\"yes\">Allows the terminal to play sound t"
  "o indicate some events.</property><property name=\"halign\">start</prop"
  "erty><property name=\"use-underline\">True</property><property name=\"d"
  "raw-indicator\">True</property></object><packing><property name=\"expan"
  "d\">True</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">5</property></packing></child><child><object class=\"Gtk"
  "CheckButton\" id=\"misc-bell-urgent\"><property name=\"label\" translat"
  "able=\"yes\">_Visual bell</property><property name=\"visible\">True</pr"
  "operty><property name=\"can-focus\">True</property><property name=\"rec"
  "eives-default\">False</property><property name=\"tooltip-text\" transla"
  "table=\"yes\">Allows the terminal to use WM\'s capability of urgent hin"
  "t to indicate some events.</property><property name=\"halign\">start</p"
  "roperty><property name=\"use-underline\">True</property><property name="
  "\"draw-indicator\">True</property></object><packing><property name=\"ex"
  "pand\">True</property><property name=\"fill\">True</property><property "
  "name=\"position\">6</property></packing></child><child><object class=\""
  "GtkBox\"><property name=\"visible\">True</property><property name=\"can"
  "-focus\">False</property><child><object class=\"GtkLabel\" id=\"label62"
  "\"><property name=\"visible\">True</property><property name=\"can-focus"
  "\">False</property><property name=\"halign\">start</property><property "
  "name=\"label\" translatable=\"yes\">Right click action: </property><pro"
  "perty name=\"use-underline\">True</property></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">0</property></packing></child><child><obje"
  "ct class=\"GtkComboBox\" id=\"misc-right-click-action\"><property name="
  "\"visible\">True</property><property name=\"can-focus\">False</property"
  "><property name=\"hexpand\">True</property><property name=\"model\">lis"
  "tstore10</property><child><object class=\"GtkCellRendererText\" id=\"ce"
  "llrenderertext12\"/><attributes><attribute name=\"text\">0</attribute><"
  "/attributes></child></object><packing><property name=\"expand\">False</"
  "property><property name=\"fill\">True</property><property name=\"positi"
  "on\">1</property></packing></child></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">7</property></packing></child></object></child></ob"
  "ject></child><child type=\"label\"><object class=\"GtkLabel\" id=\"labe"
  "l55\"><property name=\"visible\">True</property><property name=\"can-fo"
  "cus\">False</property><property name=\"label\" translatable=\"yes\">Mis"
  "c</property><attributes><attribute name=\"weight\" value=\"bold\"/></at"
  "tributes></object></child></object><packing><property name=\"expand\">F"
  "alse</property><property name=\"fill\">True</property><property name=\""
  "position\">3</property></packing></child></object><packing><property na"
  "me=\"position\">5</property></packing></child><child type=\"tab\"><obje"
  "ct class=\"GtkLabel\" id=\"label22\"><property name=\"visible\">True</p"
  "roperty><property name=\"can-focus\">False</property><property name=\"l"
  "abel\" translatable=\"yes\">Ad_vanced</property><property name=\"use-un"
  "derline\">True</property></object><packing><property name=\"position\">"
  "5</property><property name=\"tab-fill\">False</property></packing></chi"
  "ld></object><packing><property name=\"expand\">True</property><property"
  " name=\"fill\">True</property><property name=\"position\">1</property><"
  "/packing></child></object></child><action-widgets><action-widget respon"
  "se=\"1\">button-help</action-widget><action-widget response=\"0\">butto"
  "n-close</action-widget></action-widgets></object><object class=\"GtkSiz"
  "eGroup\" id=\"sizegroup1\"><widgets><widget name=\"style-label\"/><widg"
  "et name=\"opacity-label\"/></widgets></object></interface>"
};

static const unsigned terminal_preferences_ui_length = 125862u;

